@@ -36,13 +36,22 @@
 #include <KStyleManager>
 #endif
 
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if WITH_DBUS
 #include <KDBusService>
+#else
+#include <KWindowSystem>
+#include <QJsonArray>
+#include <QJsonDocument>
+#include <QWindow>
+#include <kdsingleapplication.h>
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#include <private/qtx11extras_p.h>
+#endif
 #endif
 
 int main(int argc, char *argv[])
 {
-#if HAVE_KICONTHEME && (KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0))
+#if HAVE_KICONTHEME
     KIconTheme::initTheme();
 #endif
     QApplication app(argc, argv);
@@ -54,6 +63,9 @@ int main(int argc, char *argv[])
 #if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
     QApplication::setStyle(QStringLiteral("breeze"));
 #endif
+#endif
+#if !WITH_DBUS
+    KDSingleApplication sapp;
 #endif
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("ruqola"));
 
@@ -80,6 +92,7 @@ int main(int argc, char *argv[])
     aboutData.addCredit(i18nc("@info:credit", "Allen Winter"), i18n("Packaging"), QStringLiteral("allen.winter@kdab.com"));
     aboutData.addCredit(i18nc("@info:credit", "Waqar Ahmed"), i18n("Bug fixing (compile, network crash...)"), QStringLiteral("waqar.17a@gmail.com"));
     aboutData.addCredit(i18nc("@info:credit", "Nicolas Fella"), i18n("Optimization, fix windows/mac support"), QStringLiteral("nicolas.fella@gmx.de"));
+    aboutData.addCredit(i18nc("@info:credit", "Daniele E. Domenichelli"), i18n("New feature"), QStringLiteral("daniele.domenichelli@kdab.com"));
 
     KAboutData::setApplicationData(aboutData);
 
@@ -91,7 +104,7 @@ int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 #if HAVE_KUSERFEEDBACK
-    if (parser.isSet(commandLineParser.commandLineFromEnum(RuqolaCommandLineParser::FeedBack))) {
+    if (parser.isSet(commandLineParser.commandLineFromEnum(RuqolaCommandLineParser::CommandLineName::FeedBack))) {
         auto userFeedback = new RuqolaUserFeedbackProvider;
         QTextStream(stdout) << userFeedback->describeDataSources() << '\n';
         delete userFeedback;
@@ -99,7 +112,7 @@ int main(int argc, char *argv[])
     }
 #endif
 
-    if (parser.isSet(commandLineParser.commandLineFromEnum(RuqolaCommandLineParser::ListAccount))) {
+    if (parser.isSet(commandLineParser.commandLineFromEnum(RuqolaCommandLineParser::CommandLineName::ListAccount))) {
         const QString configPath = ManagerDataPaths::self()->path(ManagerDataPaths::Config, QString());
         QDirIterator it(configPath,
                         QStringList() << QStringLiteral("ruqola.conf"),
@@ -117,7 +130,7 @@ int main(int argc, char *argv[])
 
     (void)Ruqola::self();
 
-    if (parser.isSet(commandLineParser.commandLineFromEnum(RuqolaCommandLineParser::LoginDdpApi))) {
+    if (parser.isSet(commandLineParser.commandLineFromEnum(RuqolaCommandLineParser::CommandLineName::LoginDdpApi))) {
         Ruqola::self()->setUseRestApiLogin(false);
     }
 
@@ -128,14 +141,54 @@ int main(int argc, char *argv[])
         qApp->setFont(QFont(QStringLiteral("Segoe UI Emoji")));
 #endif
     }
+#if WITH_DBUS
+    KDBusService service(KDBusService::Unique);
+#else
+    if (!sapp.isPrimaryInstance()) {
+        QJsonDocument doc;
+
+        QJsonObject obj;
+        obj[QLatin1String("working_dir")] = QDir::currentPath();
+        obj[QLatin1String("args")] = QJsonArray::fromStringList(app.arguments());
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+        if (KWindowSystem::isPlatformWayland()) {
+            obj[QLatin1String("xdg_activation_token")] = qEnvironmentVariable("XDG_ACTIVATION_TOKEN");
+        } else if (KWindowSystem::isPlatformX11()) {
+            obj[QLatin1String("startup_id")] = QString::fromUtf8(QX11Info::nextStartupId());
+        }
+#endif
+
+        doc.setObject(obj);
+
+        sapp.sendMessage(doc.toJson(QJsonDocument::Compact));
+        return 0;
+    }
+#endif
+
+    auto mw = new RuqolaMainWindow();
+#if WITH_DBUS
+    QObject::connect(&service, &KDBusService::activateRequested, mw, &RuqolaMainWindow::slotActivateRequested);
+#else
+    QApplication::connect(&sapp, &KDSingleApplication::messageReceived, &app, [mw](const QByteArray &messageData) {
+        QJsonDocument doc = QJsonDocument::fromJson(messageData);
+        QJsonObject message = doc.object();
 
 #if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
-    // TODO Port to something like KDSingleApplication
-    KDBusService service(KDBusService::Unique);
+        if (KWindowSystem::isPlatformWayland()) {
+            qputenv("XDG_ACTIVATION_TOKEN", message[QLatin1String("xdg_activation_token")].toString().toUtf8());
+        } else if (KWindowSystem::isPlatformX11()) {
+            QX11Info::setNextStartupId(message[QLatin1String("startup_id")].toString().toUtf8());
+        }
 #endif
-    auto mw = new RuqolaMainWindow();
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
-    QObject::connect(&service, &KDBusService::activateRequested, mw, &RuqolaMainWindow::slotActivateRequested);
+        QStringList arguments;
+
+        const auto argumentsJson = message[QLatin1String("args")].toArray();
+        for (const QJsonValue &val : argumentsJson) {
+            arguments << val.toString();
+        }
+
+        mw->slotActivateRequested(arguments, message[QLatin1String("working_dir")].toString());
+    });
 #endif
     mw->parseCommandLine(&parser);
 
