@@ -7,13 +7,18 @@
 #include "accountmanager.h"
 #include "localdatabase/localdatabaseutils.h"
 #include "managerdatapaths.h"
+#include "model/rocketchataccountfilterproxymodel.h"
+#include "model/rocketchataccountmodel.h"
 #include "notificationhistorymanager.h"
 #include "notifications/notifierjob.h"
 #include "rocketchataccount.h"
+#include "rocketchataccountsettings.h"
 #include "ruqola_debug.h"
+
 #include "ruqola_sound_debug.h"
 #include "ruqolaglobalconfig.h"
 #include "utils.h"
+
 #if HAVE_ACTIVITY_SUPPORT
 #include "activities/activitiesmanager.h"
 #endif
@@ -734,7 +739,7 @@ void AccountManager::connectToAccount(RocketChatAccount *account)
         NotificationHistoryManager::self()->addNotification(info);
 
         switch (info.notificationType()) {
-        case NotificationInfo::StandardMessage: {
+        case NotificationInfo::NotificationType::StandardMessage: {
             if (Room *room = account->room(info.roomId())) {
                 const QByteArray audioNotificationId = room->notificationOptions().audioNotificationValue();
                 account->playSound(audioNotificationId);
@@ -755,7 +760,7 @@ void AccountManager::connectToAccount(RocketChatAccount *account)
             job->start();
             break;
         }
-        case NotificationInfo::ConferenceCall: {
+        case NotificationInfo::NotificationType::ConferenceCall: {
             break;
         }
         }
