@@ -5,6 +5,7 @@
 */
 
 #include "authenticationmanager.h"
+#include <KLocalizedString>
 #include <KPluginFactory>
 #include <KPluginMetaData>
 #include <QFileInfo>
@@ -77,6 +78,47 @@ PluginAuthentication *AuthenticationManager::findPluginAuthentication(Authentica
     return nullptr;
 }
 
+QString AuthenticationManager::loginStatusToText(LoginStatus status)
+{
+    switch (status) {
+    case AuthenticationManager::Connecting:
+        return i18n("Connecting");
+    case AuthenticationManager::LoginOtpAuthOngoing:
+        return i18n("Login OTP code required");
+    case AuthenticationManager::LoginFailedInvalidUserOrPassword:
+        return i18n("Login failed: invalid username or password");
+    case AuthenticationManager::LoginOngoing:
+        return i18n("Logging in");
+    case AuthenticationManager::LoggedIn:
+        return i18n("Logged in");
+    case AuthenticationManager::LoggedOut:
+        return i18n("Logged out");
+    case AuthenticationManager::FailedToLoginPluginProblem:
+        return i18n("Failed to login due to plugin problem");
+    case AuthenticationManager::GenericError:
+        return i18n("Login failed: generic error");
+    case AuthenticationManager::LoginOtpRequired:
+        return i18n("A one-time password is required to complete the login procedure.");
+    case AuthenticationManager::LoginFailedInvalidOtp:
+        return i18n("Login failed: Invalid OTP code.");
+    case AuthenticationManager::LoginFailedUserNotActivated:
+        return i18n("Login failed: User is not activated.");
+    case AuthenticationManager::LoginFailedLoginBlockForIp:
+        return i18n("Login has been temporarily blocked For IP.");
+    case AuthenticationManager::LoginFailedLoginBlockedForUser:
+        return i18n("Login has been temporarily blocked For User.");
+    case AuthenticationManager::LoginFailedLoginAppNotAllowedToLogin:
+        return i18n("App user is not allowed to login.");
+    case AuthenticationManager::LogoutOngoing:
+        return i18n("Logout ongoing");
+    case AuthenticationManager::LogoutCleanUpOngoing:
+        return i18n("Logout cleanup ongoing");
+    case AuthenticationManager::LoggedOutAndCleanedUp:
+        return i18n("Successfully logged out");
+    }
+    return i18n("Unknown state");
+}
+
 QList<PluginAuthentication *> AuthenticationManager::pluginsList() const
 {
     QList<PluginAuthentication *> lst;
