@@ -74,7 +74,7 @@ public:
     //   - LoggedOutAndCleanedUp
     //   - GenericError
     // GenericError is used when the class doesn't know what else to do, and is irreversible
-    enum LoginStatus {
+    enum LoginStatus : uint8_t {
         Connecting,
         LoginOngoing,
         LoggedIn,
@@ -103,6 +103,8 @@ public:
 
     [[nodiscard]] PluginAuthentication *findPluginAuthentication(AuthenticationManager::AuthMethodType type);
 
+    [[nodiscard]] static QString loginStatusToText(LoginStatus status);
+
 private:
     explicit AuthenticationManager(QObject *parent = nullptr);
     LIBRUQOLACORE_NO_EXPORT void initializePluginList();
