@@ -7,19 +7,20 @@
 #pragma once
 #include "authenticationmanager.h"
 #include "libruqolacore_export.h"
+#include "ownuser/ownuser.h"
 #include <QObject>
 
 class LIBRUQOLACORE_EXPORT AuthenticationManagerBase : public QObject
 {
     Q_OBJECT
 public:
-    enum class Method {
+    enum class Method : uint8_t {
         Login,
         SendOtp,
         Logout,
         LogoutCleanUp,
     };
-    Q_ENUMS(Method)
+    Q_ENUM(Method)
 
     explicit AuthenticationManagerBase(QObject *parent = nullptr);
     ~AuthenticationManagerBase() override;
@@ -43,7 +44,7 @@ public:
     [[nodiscard]] bool login();
     [[nodiscard]] bool sendOTP(const QString &otp);
     void logout();
-    [[nodiscard]] bool logoutAndCleanup();
+    [[nodiscard]] bool logoutAndCleanup(const OwnUser &owser);
     [[nodiscard]] bool loginImpl(const QJsonArray &params);
 
     [[nodiscard]] QString convertMethodEnumToString(AuthenticationManagerBase::Method m);
@@ -61,6 +62,6 @@ protected:
 
     QString mAuthToken;
     QString mUserId;
-    qint64 mTokenExpires;
+    qint64 mTokenExpires = -1;
     AuthenticationManager::LoginStatus mLoginStatus = AuthenticationManager::LoggedOut;
 };
