@@ -8,7 +8,7 @@
 #include "customsound/customsoundsmanager.h"
 #include "ruqola_autotest_helper.h"
 #include <QSignalSpy>
-
+using namespace Qt::Literals::StringLiterals;
 QTEST_GUILESS_MAIN(CustomSoundsManagerTest)
 
 CustomSoundsManagerTest::CustomSoundsManagerTest(QObject *parent)
@@ -22,15 +22,6 @@ void CustomSoundsManagerTest::shouldHaveDefaultValues()
     QVERIFY(w.customSoundsInfo().isEmpty());
 }
 
-void CustomSoundsManagerTest::shouldParseCustomSounds_data()
-{
-    QTest::addColumn<QString>("name");
-    QTest::addColumn<int>("numberOfSounds");
-    {
-        QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << 5;
-    }
-}
-
 void CustomSoundsManagerTest::shouldDeleteCustomSounds()
 {
     QFETCH(QString, name);
@@ -38,7 +29,7 @@ void CustomSoundsManagerTest::shouldDeleteCustomSounds()
     QFETCH(int, initialNumberOfSounds);
     QFETCH(int, afterDeletingNumberOfSounds);
     QFETCH(int, signalsEmittingCount);
-    const QString originalJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/customsounds/") + name + QLatin1String(".json");
+    const QString originalJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/customsounds/"_L1 + name + ".json"_L1;
     const QJsonArray customSoundsArray = AutoTestHelper::loadJsonArrayObject(originalJsonFile);
     CustomSoundsManager w;
     QSignalSpy spyDeleteSignal(&w, &CustomSoundsManager::customSoundRemoved);
@@ -53,7 +44,7 @@ void CustomSoundsManagerTest::shouldDeleteCustomSounds()
     //    }
     QCOMPARE(w.customSoundsInfo().count(), initialNumberOfSounds);
 
-    QString deleteJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/customsounds/") + deleteFileName + QLatin1String(".json");
+    QString deleteJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/customsounds/"_L1 + deleteFileName + ".json"_L1;
     const QJsonArray deleteCustomSoundsArray = AutoTestHelper::loadJsonArrayObject(deleteJsonFile);
     w.deleteCustomSounds(deleteCustomSoundsArray);
     QCOMPARE(w.customSoundsInfo().count(), afterDeletingNumberOfSounds);
@@ -68,8 +59,8 @@ void CustomSoundsManagerTest::shouldDeleteCustomSounds_data()
     QTest::addColumn<int>("initialNumberOfSounds");
     QTest::addColumn<int>("afterDeletingNumberOfSounds");
     QTest::addColumn<int>("signalsEmittingCount");
-    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("deleteCustomSounds1") << 5 << 4 << 1;
-    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("deleteCustomSounds2") << 5 << 5 << 0;
+    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("deleteCustomSounds1") << 22 << 21 << 1;
+    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("deleteCustomSounds2") << 22 << 22 << 0;
 }
 
 void CustomSoundsManagerTest::shouldAddCustomSounds()
@@ -79,7 +70,7 @@ void CustomSoundsManagerTest::shouldAddCustomSounds()
     QFETCH(int, initialNumberOfSounds);
     QFETCH(int, afterDeletingNumberOfSounds);
     QFETCH(int, signalsEmittingCount);
-    const QString originalJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/customsounds/") + name + QLatin1String(".json");
+    const QString originalJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/customsounds/"_L1 + name + ".json"_L1;
     const QJsonArray customSoundsArray = AutoTestHelper::loadJsonArrayObject(originalJsonFile);
     CustomSoundsManager w;
     QSignalSpy spyAddSignal(&w, &CustomSoundsManager::customSoundAdded);
@@ -94,7 +85,7 @@ void CustomSoundsManagerTest::shouldAddCustomSounds()
     //    }
     QCOMPARE(w.customSoundsInfo().count(), initialNumberOfSounds);
 
-    QString addJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/customsounds/") + addFileName + QLatin1String(".json");
+    QString addJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/customsounds/"_L1 + addFileName + ".json"_L1;
     const QJsonArray addCustomSoundsArray = AutoTestHelper::loadJsonArrayObject(addJsonFile);
     w.updateCustomSounds(addCustomSoundsArray);
     QCOMPARE(w.customSoundsInfo().count(), afterDeletingNumberOfSounds);
@@ -109,7 +100,7 @@ void CustomSoundsManagerTest::shouldAddCustomSounds_data()
     QTest::addColumn<int>("initialNumberOfSounds");
     QTest::addColumn<int>("afterDeletingNumberOfSounds");
     QTest::addColumn<int>("signalsEmittingCount");
-    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("addCustomSounds1") << 5 << 6 << 1;
+    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("addCustomSounds1") << 22 << 23 << 1;
 }
 
 void CustomSoundsManagerTest::shouldUpdateCustomSounds()
@@ -119,7 +110,7 @@ void CustomSoundsManagerTest::shouldUpdateCustomSounds()
     QFETCH(int, initialNumberOfSounds);
     QFETCH(int, afterDeletingNumberOfSounds);
     QFETCH(int, signalsEmittingCount);
-    const QString originalJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/customsounds/") + name + QLatin1String(".json");
+    const QString originalJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/customsounds/"_L1 + name + ".json"_L1;
     const QJsonArray customSoundsArray = AutoTestHelper::loadJsonArrayObject(originalJsonFile);
     CustomSoundsManager w;
     QSignalSpy spyUpdateSignal(&w, &CustomSoundsManager::customSoundUpdated);
@@ -134,7 +125,7 @@ void CustomSoundsManagerTest::shouldUpdateCustomSounds()
     //    }
     QCOMPARE(w.customSoundsInfo().count(), initialNumberOfSounds);
 
-    QString updateJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/customsounds/") + updateFileName + QLatin1String(".json");
+    QString updateJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/customsounds/"_L1 + updateFileName + ".json"_L1;
     const QJsonArray addCustomSoundsArray = AutoTestHelper::loadJsonArrayObject(updateJsonFile);
     w.updateCustomSounds(addCustomSoundsArray);
     QCOMPARE(w.customSoundsInfo().count(), afterDeletingNumberOfSounds);
@@ -149,14 +140,14 @@ void CustomSoundsManagerTest::shouldUpdateCustomSounds_data()
     QTest::addColumn<int>("initialNumberOfSounds");
     QTest::addColumn<int>("afterDeletingNumberOfSounds");
     QTest::addColumn<int>("signalsEmittingCount");
-    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("updateCustomSounds1") << 5 << 5 << 1;
+    QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << QStringLiteral("updateCustomSounds1") << 22 << 22 << 1;
 }
 
 void CustomSoundsManagerTest::shouldParseCustomSounds()
 {
     QFETCH(QString, name);
     QFETCH(int, numberOfSounds);
-    const QString originalJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/customsounds/") + name + QLatin1String(".json");
+    const QString originalJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/customsounds/"_L1 + name + ".json"_L1;
     const QJsonArray customSoundsArray = AutoTestHelper::loadJsonArrayObject(originalJsonFile);
     CustomSoundsManager w;
     w.parseCustomSounds(customSoundsArray);
@@ -170,4 +161,13 @@ void CustomSoundsManagerTest::shouldParseCustomSounds()
     QCOMPARE(w.customSoundsInfo().count(), numberOfSounds);
 }
 
+void CustomSoundsManagerTest::shouldParseCustomSounds_data()
+{
+    QTest::addColumn<QString>("name");
+    QTest::addColumn<int>("numberOfSounds");
+    {
+        QTest::addRow("customSounds1") << QStringLiteral("customSounds1") << 22;
+    }
+}
+
 #include "moc_customsoundsmanagertest.cpp"
