@@ -7,7 +7,7 @@
 #include "filetest.h"
 #include "attachments/file.h"
 #include "ruqola_autotest_helper.h"
-
+using namespace Qt::Literals::StringLiterals;
 QTEST_GUILESS_MAIN(FileTest)
 
 FileTest::FileTest(QObject *parent)
@@ -24,7 +24,6 @@ void FileTest::shouldHaveDefaultValue()
     QVERIFY(f.url().isEmpty());
     QVERIFY(f.mimeType().isEmpty());
     QVERIFY(f.fileId().isEmpty());
-    QVERIFY(f.rid().isEmpty());
     QVERIFY(f.uploadedDateTimeStr().isEmpty());
     QCOMPARE(f.uploadedAt(), -1);
     QCOMPARE(f.complete(), false);
@@ -37,11 +36,10 @@ void FileTest::shouldAssignValue()
     const QString url = QStringLiteral("foo");
     const QString name = QStringLiteral("bla");
     const QString description = QStringLiteral("des");
-    const QString userId = QStringLiteral("ble");
+    const QByteArray userId = QByteArrayLiteral("ble");
     const QString mimetype = QStringLiteral("ble1");
     const qint64 timeUploaded = 55;
-    const QString fileId = QStringLiteral("blabla");
-    const QString rId = QStringLiteral("blabla22");
+    const QByteArray fileId("blabla");
     bool complete = false;
     f.setUrl(url);
     f.setFileName(name);
@@ -50,7 +48,6 @@ void FileTest::shouldAssignValue()
     f.setMimeType(mimetype);
     f.setUploadedAt(timeUploaded);
     f.setFileId(fileId);
-    f.setRid(rId);
     f.setComplete(complete);
 
     QCOMPARE(f.url(), url);
@@ -60,7 +57,6 @@ void FileTest::shouldAssignValue()
     QCOMPARE(f.mimeType(), mimetype);
     QCOMPARE(f.uploadedAt(), timeUploaded);
     QCOMPARE(f.fileId(), fileId);
-    QCOMPARE(f.rid(), rId);
     QCOMPARE(f.complete(), complete);
 
     complete = true;
@@ -74,10 +70,9 @@ void FileTest::shouldCopyValue()
     const QString url = QStringLiteral("foo");
     const QString name = QStringLiteral("bla");
     const QString description = QStringLiteral("des");
-    const QString userId = QStringLiteral("ble");
+    const QByteArray userId = QByteArrayLiteral("ble");
     const QString mimetype = QStringLiteral("ble1");
-    const QString fileId = QStringLiteral("blabla");
-    const QString rId = QStringLiteral("blabla22");
+    const QByteArray fileId("blabla");
     const qint64 timeUploaded = 55;
     bool complete = true;
     f.setComplete(complete);
@@ -88,7 +83,6 @@ void FileTest::shouldCopyValue()
     f.setMimeType(mimetype);
     f.setUploadedAt(timeUploaded);
     f.setFileId(fileId);
-    f.setRid(rId);
 
     File f2 = f;
     QCOMPARE(f2, f);
@@ -103,12 +97,11 @@ void FileTest::shouldParseFile_data()
         File expected;
         expected.setFileName(QStringLiteral("191135.jpg"));
         expected.setUrl(QStringLiteral("/ufs/FileSystem:Uploads/ybWLKB4FpCkzQXsa/191135.jpg"));
-        expected.setUserId(QStringLiteral("aX7va58FuNuq4bcti"));
+        expected.setUserId(QByteArrayLiteral("aX7va58FuNuq4bcti"));
         expected.setDescription(QString());
         expected.setMimeType(QStringLiteral("image/jpeg"));
         expected.setUploadedAt(1507828418338);
-        expected.setFileId(QStringLiteral("ybWLKB4FepCkzQXsa"));
-        expected.setRid(QStringLiteral("GENERAL"));
+        expected.setFileId(QByteArrayLiteral("ybWLKB4FepCkzQXsa"));
         QTest::newRow("roomfile1") << QStringLiteral("roomfile1") << expected << false;
     }
     {
@@ -116,12 +109,11 @@ void FileTest::shouldParseFile_data()
         File expected;
         expected.setFileName(QStringLiteral("Clipboard - February 7, 2018 8:59 AM"));
         expected.setUrl(QStringLiteral("/ufs/FileSystem:Uploads/AoqRSa6GMt3wXCeSo/Clipboard%20-%20February%207,%202018%208:59%20AM"));
-        expected.setUserId(QStringLiteral("vEETYfDxakqpM88Zt"));
+        expected.setUserId(QByteArrayLiteral("vEETYfDxakqpM88Zt"));
         expected.setDescription(QString());
         expected.setMimeType(QStringLiteral("image/png"));
         expected.setUploadedAt(1517990371911);
-        expected.setFileId(QStringLiteral("AoqRSa6GMt3wXCeSo"));
-        expected.setRid(QStringLiteral("GENERAL"));
+        expected.setFileId(QByteArrayLiteral("AoqRSa6GMt3wXCeSo"));
         expected.setUserName(QStringLiteral("bli"));
         expected.setComplete(true);
         QTest::newRow("roomfile1-restapi") << QStringLiteral("roomfile1") << expected << true;
@@ -135,9 +127,9 @@ void FileTest::shouldParseFile()
     QFETCH(bool, usingRestApi);
     QString originalJsonFile;
     if (usingRestApi) {
-        originalJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/json/restapi/") + fileName + QLatin1String(".json");
+        originalJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/json/restapi/"_L1 + fileName + ".json"_L1;
     } else {
-        originalJsonFile = QLatin1String(RUQOLA_DATA_DIR) + QLatin1String("/json/") + fileName + QLatin1String(".json");
+        originalJsonFile = QLatin1StringView(RUQOLA_DATA_DIR) + "/json/"_L1 + fileName + ".json"_L1;
     }
     const QJsonObject fields = AutoTestHelper::loadJsonObject(originalJsonFile);
 
