@@ -20,14 +20,6 @@ void RocketChatMessageTest::compareFile(const QString &data, const QString &name
     AutoTestHelper::compareFile(QStringLiteral("/method/"), data.toUtf8(), name);
 }
 
-void RocketChatMessageTest::shouldJoinRoom()
-{
-    RocketChatMessage m;
-    m.setJsonFormat(QJsonDocument::Indented);
-    RocketChatMessage::RocketChatMessageResult r = m.joinRoom(QByteArray("foo"), QStringLiteral("access_code"), 43);
-    compareFile(r.result, QStringLiteral("joinroom"));
-}
-
 void RocketChatMessageTest::shouldSetDefaultStatus()
 {
     RocketChatMessage m;
@@ -130,41 +122,6 @@ void RocketChatMessageTest::setAdminStatus()
     }
 }
 
-void RocketChatMessageTest::deleteOAuthApp()
-{
-    RocketChatMessage m;
-    m.setJsonFormat(QJsonDocument::Indented);
-    RocketChatMessage::RocketChatMessageResult r = m.deleteOAuthApp(QStringLiteral("oauthappid"), 43);
-    compareFile(r.result, QStringLiteral("deleteOAuthApp"));
-}
-
-void RocketChatMessageTest::addOAuthApp()
-{
-    {
-        RocketChatMessage m;
-        m.setJsonFormat(QJsonDocument::Indented);
-        RocketChatMessage::RocketChatMessageResult r = m.addOAuthApp(QStringLiteral("oauthappname"), true, QStringLiteral("url"), 43);
-        compareFile(r.result, QStringLiteral("addOAuthApp"));
-    }
-    {
-        RocketChatMessage m;
-        m.setJsonFormat(QJsonDocument::Indented);
-        RocketChatMessage::RocketChatMessageResult r = m.addOAuthApp(QStringLiteral("oauthappname"), false, QStringLiteral("url"), 43);
-        compareFile(r.result, QStringLiteral("addOAuthApp-disabled"));
-    }
-}
-
-void RocketChatMessageTest::updateOAuthApp()
-{
-    // TODO
-    {
-        RocketChatMessage m;
-        m.setJsonFormat(QJsonDocument::Indented);
-        RocketChatMessage::RocketChatMessageResult r = m.addOAuthApp(QStringLiteral("updateoauthappname"), true, QStringLiteral("url"), 43);
-        compareFile(r.result, QStringLiteral("updateOAuthApp"));
-    }
-}
-
 void RocketChatMessageTest::unBlockUser()
 {
     RocketChatMessage m;
@@ -327,4 +284,13 @@ void RocketChatMessageTest::videoConferenceConfirmed()
     compareFile(r.result, QStringLiteral("videoConferenceConfirmed"));
 }
 
+void RocketChatMessageTest::getRoomByTypeAndName()
+{
+    RocketChatMessage m;
+    m.setJsonFormat(QJsonDocument::Indented);
+
+    RocketChatMessage::RocketChatMessageResult r = m.getRoomByTypeAndName(QByteArrayLiteral("oHfocsBTwc9bSdAxt"), QStringLiteral("c"), 43);
+    compareFile(r.result, QStringLiteral("getRoomByTypeAndName"));
+}
+
 #include "moc_rocketchatmessagetest.cpp"
