@@ -5,7 +5,6 @@
 */
 
 #include "roomtest.h"
-#include "model/usersforroommodel.h"
 #include "rocketchataccount.h"
 #include "room.h"
 #include "ruqola_autotest_helper.h"
@@ -86,6 +85,8 @@ void RoomTest::shouldHaveDefaultValue()
     QVERIFY(!w.muteGroupMentions());
     QVERIFY(w.audioNotificationValue().isEmpty());
 
+    QCOMPARE(input.lastOpenedAt(), -1);
+
     // 26/03/2024: size: 1040
     QCOMPARE(sizeof(Room), 792);
 }
@@ -324,6 +325,20 @@ void RoomTest::shouldEmitSignals()
     QCOMPARE(spylastMessageAtChanged.count(), 1);
 }
 
+void RoomTest::shoudUserIsMuted()
+{
+    {
+        Room input(nullptr);
+        input.setMutedUsers(QStringList());
+        QVERIFY(!input.userIsMuted("foo"_L1));
+
+        QStringList lst;
+        lst << QStringLiteral("bla") << QStringLiteral("foo");
+        input.setMutedUsers(lst);
+        QVERIFY(input.userIsMuted("foo"_L1));
+    }
+}
+
 void RoomTest::shouldParseRoom_data()
 {
     QTest::addColumn<QString>("fileName");
