@@ -9,13 +9,13 @@
 #include "bannerinfo.h"
 #include "libruqolacore_export.h"
 #include <QDebug>
-#include <QVector>
+#include <QList>
 
 class LIBRUQOLACORE_EXPORT BannerInfos
 {
 public:
     struct UnreadInformation {
-        QString identifier;
+        QByteArray identifier;
         QString i18nMessage;
         [[nodiscard]] bool operator==(const UnreadInformation &other) const
         {
@@ -30,14 +30,14 @@ public:
     BannerInfos();
     ~BannerInfos();
 
-    [[nodiscard]] const QVector<BannerInfo> &banners() const;
-    void setBanners(const QVector<BannerInfo> &newBanners);
+    [[nodiscard]] const QList<BannerInfo> &banners() const;
+    void setBanners(const QList<BannerInfo> &newBanners);
 
     void parseBannerInfos(const QJsonObject &object);
 
     void clear();
 
-    void updateBannerReadInfo(const QString &name, bool readStatus);
+    void updateBannerReadInfo(const QByteArray &name, bool readStatus);
 
     [[nodiscard]] int count() const;
 
@@ -45,14 +45,14 @@ public:
 
     [[nodiscard]] BannerInfo at(int index) const;
 
-    [[nodiscard]] QVector<BannerInfos::UnreadInformation> bannerUnreadInformations() const;
+    [[nodiscard]] QList<BannerInfos::UnreadInformation> bannerUnreadInformations() const;
 
 private:
     [[nodiscard]] LIBRUQOLACORE_NO_EXPORT QString generateText(const BannerInfo &info) const;
-    QVector<BannerInfo> mBanners;
+    QList<BannerInfo> mBanners;
 };
 
 Q_DECLARE_METATYPE(BannerInfos)
 Q_DECLARE_METATYPE(BannerInfos::UnreadInformation)
-Q_DECLARE_TYPEINFO(BannerInfos::UnreadInformation, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(BannerInfos::UnreadInformation, Q_RELOCATABLE_TYPE);
 LIBRUQOLACORE_EXPORT QDebug operator<<(QDebug d, const BannerInfos &t);
