@@ -15,8 +15,8 @@ public:
     CustomSoundInfo();
     ~CustomSoundInfo() = default;
 
-    [[nodiscard]] const QString &identifier() const;
-    void setIdentifier(const QString &newIdentifier);
+    [[nodiscard]] const QByteArray &identifier() const;
+    void setIdentifier(const QByteArray &newIdentifier);
 
     [[nodiscard]] const QString &name() const;
     void setName(const QString &newName);
@@ -28,12 +28,18 @@ public:
 
     [[nodiscard]] bool isValid() const;
 
+    [[nodiscard]] bool defaultSound() const;
+    void setDefaultSound(bool newDefaultSound);
+
+    [[nodiscard]] QString generateUrl() const;
+
 private:
-    QString mIdentifier;
+    QByteArray mIdentifier;
     QString mName;
     QString mExtension;
+    bool mDefaultSound = false;
 };
 
 Q_DECLARE_METATYPE(CustomSoundInfo)
-Q_DECLARE_TYPEINFO(CustomSoundInfo, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(CustomSoundInfo, Q_RELOCATABLE_TYPE);
 LIBRUQOLACORE_EXPORT QDebug operator<<(QDebug d, const CustomSoundInfo &t);
