@@ -30,9 +30,9 @@ public:
     void loadAccountSettings();
 
 private:
-    void syncMessage(const QString &roomId, qint64 lastSeenAt);
-    void slotSyncMessages(const QJsonObject &obj, const QString &roomId);
+    LIBRUQOLACORE_NO_EXPORT void syncMessage(const QByteArray &roomId, qint64 lastSeenAt);
+    LIBRUQOLACORE_NO_EXPORT void slotSyncMessages(const QJsonObject &obj, const QByteArray &roomId);
     RocketChatAccount *const mRocketChatAccount;
 };
-Q_DECLARE_TYPEINFO(ManageLocalDatabase::ManageLoadHistoryInfo, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(ManageLocalDatabase::ManageLoadHistoryInfo, Q_RELOCATABLE_TYPE);
 LIBRUQOLACORE_EXPORT QDebug operator<<(QDebug d, const ManageLocalDatabase::ManageLoadHistoryInfo &t);
