@@ -123,7 +123,7 @@ QList<int> AdminCustomSoundModel::hideColumns() const
     return {CustomSoundsRoles::Identifier};
 }
 
-void AdminCustomSoundModel::removeElement(const QString &identifier)
+void AdminCustomSoundModel::removeElement(const QByteArray &identifier)
 {
     const int userCount = mCustomSounds.count();
     for (int i = 0; i < userCount; ++i) {
