@@ -45,6 +45,7 @@ QVariant AdminRoomsModel::headerData(int section, Qt::Orientation orientation, i
             return i18n("Type");
         case AdminRoomsRoles::IsTeam:
         case AdminRoomsRoles::Featured:
+        case AdminRoomsRoles::IsDiscussion:
             return {};
         }
     }
@@ -92,6 +93,8 @@ QVariant AdminRoomsModel::data(const QModelIndex &index, int role) const
         return adminroom.featured();
     case AdminRoomsRoles::IsTeam:
         return adminroom.isTeam();
+    case AdminRoomsRoles::IsDiscussion:
+        return adminroom.isDiscussion();
     }
 
     return {};
@@ -128,7 +131,7 @@ void AdminRoomsModel::parseElements(const QJsonObject &obj)
         mAdminRooms.clear();
         endRemoveRows();
     }
-    mAdminRooms.parseRooms(obj, RoomsInfo::Administrator);
+    mAdminRooms.parseRooms(obj, RoomsInfo::ParseType::Administrator);
     if (!mAdminRooms.isEmpty()) {
         beginInsertRows(QModelIndex(), 0, mAdminRooms.count() - 1);
         endInsertRows();
@@ -145,7 +148,7 @@ void AdminRoomsModel::checkFullList()
 void AdminRoomsModel::addMoreElements(const QJsonObject &obj)
 {
     const int numberOfElement = mAdminRooms.count();
-    mAdminRooms.parseMoreRooms(obj, RoomsInfo::Directory);
+    mAdminRooms.parseMoreRooms(obj, RoomsInfo::ParseType::Directory);
     beginInsertRows(QModelIndex(), numberOfElement, mAdminRooms.count() - 1);
     endInsertRows();
     checkFullList();
