@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,15 +22,14 @@ public:
 
     explicit AutotranslateLanguagesModel(QObject *parent = nullptr);
     ~AutotranslateLanguagesModel() override;
-    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
     void parseLanguages(const QJsonObject &obj);
 
-    Q_REQUIRED_RESULT int currentLanguage(const QString &lang) const;
-    Q_REQUIRED_RESULT QString selectedLanguage(int index) const;
+    [[nodiscard]] int currentLanguage(const QString &lang) const;
+    [[nodiscard]] QString selectedLanguage(int index) const;
 
 private:
     AutotranslateLanguages mAutoTranslateLanguages;
-    int mCurrentLanguage = 0;
 };
