@@ -19,5 +19,5 @@ public:
     void clear();
 
 protected:
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+    [[nodiscard]] bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 };
