@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,20 +22,21 @@ public:
         Parameters,
         TranslatedDescription,
         TranslatedParams,
+        Permissions,
     };
     Q_ENUM(CommandsRoles)
 
     explicit CommandsModel(QObject *parent = nullptr);
     ~CommandsModel() override;
 
-    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
 
-    Q_REQUIRED_RESULT Commands commands() const;
+    [[nodiscard]] Commands commands() const;
 
     void setCommands(const Commands &emoticons);
 
 private:
-    Q_DISABLE_COPY(CommandsModel)
+    LIBRUQOLACORE_NO_EXPORT void clear();
     Commands mCommands;
 };
