@@ -109,7 +109,7 @@ QVariant FilesForRoomModel::data(const QModelIndex &index, int role) const
         return {};
     }
 
-    const File &file = mFileAttachments->fileAttachments().at(index.row());
+    const File &file = mFileAttachments->fileAttachments()[index.row()];
     switch (role) {
     case FilePointer:
         return QVariant::fromValue(&file);
