@@ -9,15 +9,14 @@
 #include "libruqolacore_export.h"
 #include <QAbstractListModel>
 
-struct NotificationDesktopDurationPreferenceInfo {
-    QString displayText;
-    QString preference;
-};
-
 class LIBRUQOLACORE_EXPORT NotificationDesktopDurationPreferenceModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
+    struct NotificationDesktopDurationPreferenceInfo {
+        QString displayText;
+        QString preference;
+    };
     enum NotificationPreferenceRoles {
         NotificationPreferenceI18n = Qt::UserRole + 1,
         NotificationPreference,
@@ -39,6 +38,8 @@ Q_SIGNALS:
 
 private:
     LIBRUQOLACORE_NO_EXPORT void fillModel();
-    QVector<NotificationDesktopDurationPreferenceInfo> mNotificationDestktopDurationPreferenceList;
+    QList<NotificationDesktopDurationPreferenceInfo> mNotificationDestktopDurationPreferenceList;
     int mCurrentPreference = 0;
 };
+Q_DECLARE_METATYPE(NotificationDesktopDurationPreferenceModel::NotificationDesktopDurationPreferenceInfo)
+Q_DECLARE_TYPEINFO(NotificationDesktopDurationPreferenceModel::NotificationDesktopDurationPreferenceInfo, Q_RELOCATABLE_TYPE);
