@@ -6,10 +6,9 @@
 
 #pragma once
 
-#include <QAbstractItemModel>
-
 #include "libruqolacore_export.h"
 #include "utils.h"
+#include <QAbstractListModel>
 
 class LIBRUQOLACORE_EXPORT SwitchChannelHistoryModel : public QAbstractListModel
 {
@@ -24,7 +23,7 @@ public:
 
     struct SwitchChannelInfo {
         SwitchChannelInfo() = default;
-        SwitchChannelInfo(const QString &name, const QString &identifier, const Utils::AvatarInfo &info)
+        SwitchChannelInfo(const QString &name, const QByteArray &identifier, const Utils::AvatarInfo &info)
             : mName(name)
             , mIdentifier(identifier)
             , mAvatarInfo(info)
@@ -32,7 +31,7 @@ public:
         }
         [[nodiscard]] bool operator==(const SwitchChannelInfo &other) const;
         QString mName;
-        QString mIdentifier;
+        QByteArray mIdentifier;
         Utils::AvatarInfo mAvatarInfo;
     };
 
@@ -45,8 +44,8 @@ public:
     void addHistory(const SwitchChannelInfo &info);
 
 private:
-    QVector<SwitchChannelInfo> mSwichChannelsInfo;
+    QList<SwitchChannelInfo> mSwichChannelsInfo;
 };
 
 Q_DECLARE_METATYPE(SwitchChannelHistoryModel::SwitchChannelInfo)
-Q_DECLARE_TYPEINFO(SwitchChannelHistoryModel::SwitchChannelInfo, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(SwitchChannelHistoryModel::SwitchChannelInfo, Q_RELOCATABLE_TYPE);
