@@ -10,19 +10,20 @@
 #include <QDebug>
 #include <QString>
 
-class LIBRUQOLACORE_EXPORT ModerationMessage
+class LIBRUQOLACORE_EXPORT ModerationMessage : public QSharedData
 {
 public:
+    explicit ModerationMessage(const ModerationMessage &other);
     ModerationMessage();
     ~ModerationMessage();
 
-    [[nodiscard]] QString moderationId() const;
-    void setModerationId(const QString &newModerationId);
+    [[nodiscard]] QByteArray moderationId() const;
+    void setModerationId(const QByteArray &newModerationId);
 
     void parse(const QJsonObject &obj);
 
-    [[nodiscard]] QString roomId() const;
-    void setRoomId(const QString &newRoomId);
+    [[nodiscard]] QByteArray roomId() const;
+    void setRoomId(const QByteArray &newRoomId);
 
     [[nodiscard]] QString roomName() const;
     void setRoomName(const QString &newRoomName);
@@ -31,11 +32,12 @@ public:
     void setRoomFName(const QString &newRoomFName);
 
     [[nodiscard]] bool isEmpty() const;
+    [[nodiscard]] bool operator==(const ModerationMessage &other) const;
 
 private:
     LIBRUQOLACORE_NO_EXPORT void parseRoom(const QJsonObject &roomObj);
-    QString mModerationId;
-    QString mRoomId;
+    QByteArray mModerationId;
+    QByteArray mRoomId;
     QString mRoomName;
     QString mRoomFName;
 };
