@@ -5,6 +5,8 @@
 */
 
 #include "personalaccesstokeninfos.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "ruqola_debug.h"
 
 #include <QJsonArray>
@@ -12,7 +14,7 @@
 
 PersonalAccessTokenInfos::PersonalAccessTokenInfos() = default;
 
-QVector<PersonalAccessTokenInfo> PersonalAccessTokenInfos::personalAccessTokenInfos() const
+QList<PersonalAccessTokenInfo> PersonalAccessTokenInfos::personalAccessTokenInfos() const
 {
     return mPersonalAccessTokenInfos;
 }
@@ -46,7 +48,7 @@ bool PersonalAccessTokenInfos::isEmpty() const
     return mPersonalAccessTokenInfos.isEmpty();
 }
 
-void PersonalAccessTokenInfos::setPersonalAccessTokenInfos(const QVector<PersonalAccessTokenInfo> &tokenInfos)
+void PersonalAccessTokenInfos::setPersonalAccessTokenInfos(const QList<PersonalAccessTokenInfo> &tokenInfos)
 {
     mPersonalAccessTokenInfos = tokenInfos;
 }
@@ -54,7 +56,7 @@ void PersonalAccessTokenInfos::setPersonalAccessTokenInfos(const QVector<Persona
 void PersonalAccessTokenInfos::parsePersonalAccessTokenInfos(const QJsonObject &obj)
 {
     mPersonalAccessTokenInfos.clear();
-    const QJsonArray tokensArray = obj[QLatin1String("tokens")].toArray();
+    const QJsonArray tokensArray = obj["tokens"_L1].toArray();
     const auto tokensArrayCount = tokensArray.count();
     mPersonalAccessTokenInfos.reserve(tokensArrayCount);
     for (auto i = 0; i < tokensArrayCount; ++i) {
