@@ -47,7 +47,6 @@ public:
     void setTwoFactorAuthenticationCode(const QString &twoFactorAuthenticationCode);
 
     void logout();
-    [[nodiscard]] QString cacheBasePath();
 
     [[nodiscard]] QString password() const;
     void setPassword(const QString &password);
@@ -80,15 +79,20 @@ public:
     [[nodiscard]] bool activityEnabled() const;
     void setActivityEnabled(bool newActivityEnabled);
 
+    [[nodiscard]] int cacheVersion() const;
+    void setCacheVersion(int newVersion);
+
+    [[nodiscard]] bool keySaved() const;
+    void setKeySaved(bool newKeySaved);
+
 Q_SIGNALS:
     void serverURLChanged();
     void userNameChanged();
     void userIdChanged();
     void accountNameChanged();
-    void passwordChanged();
+    void passwordAvailable();
     void twoFactorAuthenticationCodeChanged();
     void enableAccountChanged();
-    void displayNameChanged();
     void activitiesChanged();
 
 private:
@@ -102,7 +106,6 @@ private:
     QString mServerUrl;
     QString mAccountName;
     QString mDisplayName;
-    QString mCachePath;
     QString mUserName;
     QString mPassword;
     QStringList mActivities;
@@ -110,6 +113,7 @@ private:
     QString mTwoFactorAuthenticationCode;
     qint64 mExpireToken = -1;
     QSettings *mSetting = nullptr;
+    bool mKeySaved = false;
     bool mUseLdap = false;
     bool mAccountEnabled = true;
     bool mActivityEnabled = false;
