@@ -10,16 +10,17 @@
 #include "rocketchatbackend.h"
 #include "ruqola_authentication_debug.h"
 #include "ruqola_reconnect_core_debug.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "authenticationmanager/ddpauthenticationmanager.h"
 #include "config-ruqola.h"
 #include "connection.h"
 #include "ddpapi/ddpclient.h"
 #include "model/messagesmodel.h"
+#include "model/roommodel.h"
 #include "model/usersmodel.h"
 #include "receivetypingnotificationmanager.h"
 #include "rocketchataccount.h"
+#include "rocketchataccountsettings.h"
 #include "ruqola.h"
 #include "ruqola_debug.h"
 #include "ruqola_message_debug.h"
@@ -30,6 +31,7 @@ using namespace Qt::Literals::StringLiterals;
 #include "authenticationmanager/restauthenticationmanager.h"
 #include "connection.h"
 #include <QJsonArray>
+using namespace Qt::Literals::StringLiterals;
 
 void process_updatePublicsettings(const QJsonObject &obj, RocketChatAccount *account)
 {
@@ -64,6 +66,26 @@ void process_publicsettings_administrator(const QJsonObject &obj, RocketChatAcco
     }
 }
 
+void process_privatesettings_administrator(const QJsonObject &obj, RocketChatAccount *account)
+{
+    Q_EMIT account->privateSettingLoaded(obj);
+
+    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
+    if (account->ruqolaLogger()) {
+        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Administrator Private Settings:") + QJsonDocument(obj).toJson());
+    }
+}
+
+void process_permissions_administrator(const QJsonObject &obj, RocketChatAccount *account)
+{
+    Q_EMIT account->permissionSettingLoaded(obj);
+
+    // qCDebug(RUQOLA_LOG) << " configs"<<configs;
+    if (account->ruqolaLogger()) {
+        account->ruqolaLogger()->dataReceived(QByteArrayLiteral("Administrator Permissions:") + QJsonDocument(obj).toJson());
+    }
+}
+
 void rooms_parsing(const QJsonObject &root, RocketChatAccount *account)
 {
     const QJsonObject obj = root.value("result"_L1).toObject();
@@ -140,7 +162,7 @@ void getsubscription_parsing(const QJsonObject &root, RocketChatAccount *account
     // TODO use timeStamp too
     params["$date"_L1] = QJsonValue(0); // get ALL rooms we've ever seen
     // Add timestamp https://developer.rocket.chat/reference/api/realtime-api/method-calls/get-rooms
-    account->ddp()->method(QStringLiteral("rooms/get"), QJsonDocument(params), rooms_parsing);
+    account->ddp()->method(QStringLiteral("rooms/get"), params, rooms_parsing);
 
     account->initializeAccount();
 }
@@ -154,27 +176,33 @@ RocketChatBackend::RocketChatBackend(RocketChatAccount *account, QObject *parent
     connect(mRocketChatAccount, &RocketChatAccount::changed, this, &RocketChatBackend::slotChanged);
     connect(mRocketChatAccount, &RocketChatAccount::added, this, &RocketChatBackend::slotAdded);
     connect(mRocketChatAccount, &RocketChatAccount::removed, this, &RocketChatBackend::slotRemoved);
-    connect(mRocketChatAccount, &RocketChatAccount::connectedChanged, this, &RocketChatBackend::slotConnectedChanged);
-    connect(mRocketChatAccount, &RocketChatAccount::passwordChanged, this, &RocketChatBackend::tryAutoLogin);
+    connect(mRocketChatAccount, &RocketChatAccount::ddpConnectedChanged, this, &RocketChatBackend::slotDDPConnectedChanged);
+    connect(mRocketChatAccount, &RocketChatAccount::passwordAvailable, this, &RocketChatBackend::tryAutoLogin);
 }
 
 RocketChatBackend::~RocketChatBackend() = default;
 
-// TODO load public info even if we are not connected.
-void RocketChatBackend::slotConnectedChanged()
+void RocketChatBackend::loadServerInfo()
 {
-    auto ddp = mRocketChatAccount->ddp();
-    if (!ddp->isConnected()) {
-        return;
-    }
-
     auto restApi = mRocketChatAccount->restApi();
 
     restApi->serverInfo();
     connect(restApi, &Connection::serverInfoDone, this, &RocketChatBackend::parseServerVersionDone, Qt::UniqueConnection);
     connect(restApi, &Connection::privateInfoDone, this, &RocketChatBackend::slotPrivateInfoDone, Qt::UniqueConnection);
+}
 
-    mRocketChatAccount->loadAccountSettings();
+void RocketChatBackend::slotDDPConnectedChanged(bool connected)
+{
+    if (connected) {
+        // This ends up calling loadPublicSettings() below
+        mRocketChatAccount->loadAccountSettings();
+
+        // In RestAPI-login mode (the default), we can only DDP-login if we have an auth token from rest api
+        auto restApi = mRocketChatAccount->restApi();
+        if (!Ruqola::useRestApiLogin() || (restApi && restApi->authenticationManager()->isLoggedIn())) {
+            ddpLogin();
+        }
+    }
 }
 
 void RocketChatBackend::loadPublicSettings(qint64 timeStamp)
@@ -186,12 +214,44 @@ void RocketChatBackend::loadPublicSettings(qint64 timeStamp)
         // "params": [ { "$date": 1480377601 } ]
         params["$date"_L1] = timeStamp;
         qDebug() << "RocketChatBackend::loadPublicSettings load from: " << params;
-        ddp->method(QStringLiteral("public-settings/get"), QJsonDocument(params), process_updatePublicsettings);
+        ddp->method(QStringLiteral("public-settings/get"), params, process_updatePublicsettings);
     } else {
-        ddp->method(QStringLiteral("public-settings/get"), QJsonDocument(params), process_publicsettings);
+        ddp->method(QStringLiteral("public-settings/get"), params, process_publicsettings);
     }
 }
 
+void RocketChatBackend::loadPermissionsAdministrator(qint64 timeStamp)
+{
+    auto ddp = mRocketChatAccount->ddp();
+    if (!ddp->isConnected()) {
+        return;
+    }
+    // https://developer.rocket.chat/docs/get-permissions
+    QJsonObject params;
+    if (timeStamp != -1) {
+        // "params": [ { "$date": 1480377601 } ]
+        params["$date"_L1] = timeStamp;
+    }
+    qDebug() << " params " << params;
+    ddp->method(QStringLiteral("permissions/get"), params, process_permissions_administrator);
+}
+
+void RocketChatBackend::loadPrivateSettingsAdministrator(qint64 timeStamp)
+{
+    auto ddp = mRocketChatAccount->ddp();
+    if (!ddp->isConnected()) {
+        return;
+    }
+    // https://developer.rocket.chat/docs/get-permissions
+    QJsonObject params;
+    if (timeStamp != -1) {
+        // "params": [ { "$date": 1480377601 } ]
+        params["$date"_L1] = timeStamp;
+    }
+    qDebug() << " params " << params;
+    ddp->method(QStringLiteral("private-settings/get"), params, process_privatesettings_administrator);
+}
+
 void RocketChatBackend::loadPublicSettingsAdministrator(qint64 timeStamp)
 {
     auto ddp = mRocketChatAccount->ddp();
@@ -205,7 +265,7 @@ void RocketChatBackend::loadPublicSettingsAdministrator(qint64 timeStamp)
         params["$date"_L1] = timeStamp;
     }
     qDebug() << " params " << params;
-    ddp->method(QStringLiteral("public-settings/get"), QJsonDocument(params), process_publicsettings_administrator);
+    ddp->method(QStringLiteral("public-settings/get"), params, process_publicsettings_administrator);
 }
 
 void RocketChatBackend::updateVideoConferenceInfo(const Message &m)
@@ -312,7 +372,7 @@ void RocketChatBackend::processIncomingMessages(const QJsonArray &messages, bool
     }
 }
 
-void RocketChatBackend::connectDdpClient()
+void RocketChatBackend::ddpLogin()
 {
     auto restApi = mRocketChatAccount->restApi();
     auto ddp = mRocketChatAccount->ddp();
@@ -320,10 +380,10 @@ void RocketChatBackend::connectDdpClient()
     ddp->authenticationManager()->setAuthToken(restApi->authenticationManager()->authToken());
     // if (ddp->authenticationManager()->loginPassword(mRocketChatAccount->settings()->userName(), mRocketChatAccount->settings()->password())) {
     if (ddp->authenticationManager()->login()) {
-        qCDebug(RUQOLA_AUTHENTICATION_LOG) << " login ok" << mRocketChatAccount->accountName() << mRocketChatAccount->userName();
+        qCDebug(RUQOLA_AUTHENTICATION_LOG) << "ddpLogin: login ok" << mRocketChatAccount->accountName() << mRocketChatAccount->userName();
         initializeSubscription(ddp);
     } else {
-        qCWarning(RUQOLA_AUTHENTICATION_LOG) << " impossible to reconnect" << mRocketChatAccount->accountName() << mRocketChatAccount->userName();
+        qCWarning(RUQOLA_AUTHENTICATION_LOG) << "ddpLogin: could not reconnect" << mRocketChatAccount->accountName() << mRocketChatAccount->userName();
     }
 }
 
@@ -331,7 +391,7 @@ void RocketChatBackend::slotLoginStatusChanged()
 {
     if (mRocketChatAccount->loginStatus() == AuthenticationManager::LoggedIn) {
         auto restApi = mRocketChatAccount->restApi();
-        if (Ruqola::self()->useRestApiLogin()) {
+        if (Ruqola::useRestApiLogin()) {
             mRocketChatAccount->settings()->setAuthToken(restApi->authenticationManager()->authToken());
             mRocketChatAccount->settings()->setExpireToken(restApi->authenticationManager()->tokenExpires());
 
@@ -339,7 +399,9 @@ void RocketChatBackend::slotLoginStatusChanged()
             restApi->setAuthToken(restApi->authenticationManager()->authToken());
             restApi->setUserId(restApi->authenticationManager()->userId());
 
-            connectDdpClient();
+            if (mRocketChatAccount->ddp()->isConnected()) {
+                ddpLogin();
+            }
         } else {
             // Now that we are logged in the ddp authentication manager has all the information we need
             mRocketChatAccount->settings()->setAuthToken(mRocketChatAccount->ddp()->authenticationManager()->authToken());
@@ -368,7 +430,7 @@ void RocketChatBackend::initializeSubscription(DDPClient *ddp)
         getsubscription_parsing(obj, account);
     };
 
-    ddp->method(QStringLiteral("subscriptions/get"), QJsonDocument(params), subscription_callback);
+    ddp->method(QStringLiteral("subscriptions/get"), params, subscription_callback);
 }
 
 void RocketChatBackend::slotPrivateInfoDone(const QJsonObject &data)
@@ -385,43 +447,33 @@ void RocketChatBackend::parseServerVersionDone(const QString &version)
 
 void RocketChatBackend::tryAutoLogin()
 {
-    qCDebug(RUQOLA_RECONNECT_LOG) << " mRocketChatAccount->accountName" << mRocketChatAccount->accountName();
+    qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin for account" << mRocketChatAccount->accountName();
+    if (mRocketChatAccount->serverVersion().isEmpty()) {
+        qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: can't autologin yet, waiting for parseServerVersionDone";
+        return;
+    }
     if (mRocketChatAccount->authMethodType() == AuthenticationManager::AuthMethodType::Password) {
-        if (mRocketChatAccount->serverVersion().isEmpty() || mRocketChatAccount->password().isEmpty()) {
-            qCWarning(RUQOLA_RECONNECT_LOG) << " Impossible to log: mRocketChatAccount->serverVersion().isEmpty()"
-                                            << mRocketChatAccount->serverVersion().isEmpty() << "mRocketChatAccount->password().isEmpty() "
-                                            << mRocketChatAccount->password().isEmpty();
+        if (mRocketChatAccount->password().isEmpty()) {
+            qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: can't autologin (yet?), no password set";
             return;
         }
     } else if (mRocketChatAccount->authMethodType() == AuthenticationManager::AuthMethodType::PersonalAccessToken) {
-        if (mRocketChatAccount->serverVersion().isEmpty() || mRocketChatAccount->authToken().isEmpty()) {
-            qCWarning(RUQOLA_RECONNECT_LOG) << " Impossible to log: mRocketChatAccount->serverVersion().isEmpty()"
-                                            << mRocketChatAccount->serverVersion().isEmpty() << "mRocketChatAccount->authToken().isEmpty() "
-                                            << mRocketChatAccount->authToken().isEmpty();
+        if (mRocketChatAccount->authToken().isEmpty()) {
+            qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: can't autologin (yet?), no authToken";
             return;
         }
     } else {
-        qCWarning(RUQOLA_RECONNECT_LOG) << " tryAutoLogin check not implemented for " << mRocketChatAccount->authMethodType();
+        qCWarning(RUQOLA_RECONNECT_LOG) << " tryAutoLogin: check not implemented for " << mRocketChatAccount->authMethodType();
     }
-    if (Ruqola::self()->useRestApiLogin()) {
-        qCWarning(RUQOLA_RECONNECT_LOG) << "try login REST API" << mRocketChatAccount->accountName();
+    if (Ruqola::useRestApiLogin()) {
+        qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: try login REST API" << mRocketChatAccount->accountName();
         mRocketChatAccount->tryLogin();
     } else {
-        qCWarning(RUQOLA_RECONNECT_LOG) << "try login ddp" << mRocketChatAccount->accountName();
+        qCDebug(RUQOLA_RECONNECT_LOG) << "tryAutoLogin: try login ddp" << mRocketChatAccount->accountName();
         mRocketChatAccount->ddp()->login();
     }
 }
 
-QList<File> RocketChatBackend::files() const
-{
-    return mFiles;
-}
-
-QList<User> RocketChatBackend::users() const
-{
-    return mUsers;
-}
-
 void RocketChatBackend::slotRemoved(const QJsonObject &object)
 {
     const QString collection = object.value("collection"_L1).toString();
@@ -480,6 +532,7 @@ void RocketChatBackend::slotAdded(const QJsonObject &object)
         // qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << mRocketChatAccount->accountName() << ":stream-notify-all: " << object;
         // TODO verify that all is ok !
     } else if (collection == "autocompleteRecords"_L1) {
+        qWarning() << "autocompleteRecords: Necessary to implement autocompleteRecords !!!!!";
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(object);
@@ -487,10 +540,9 @@ void RocketChatBackend::slotAdded(const QJsonObject &object)
         } else {
             qCDebug(RUQOLA_LOG) << "AutoCompleteRecords VALUE" << object;
         }
-        User user;
-        user.parseUser(object);
-        mUsers.append(std::move(user));
     } else if (collection == "room_files"_L1) {
+        qWarning() << " Necessary to implement room_files !!!!!";
+        /*
         if (mRocketChatAccount->ruqolaLogger()) {
             QJsonDocument d;
             d.setObject(object);
@@ -501,6 +553,7 @@ void RocketChatBackend::slotAdded(const QJsonObject &object)
         File file;
         file.parseFile(object, false);
         mFiles.append(std::move(file));
+        */
     } else if (collection == "stream-notify-room"_L1) {
         // qCDebug(RUQOLA_UNKNOWN_COLLECTIONTYPE_LOG) << mRocketChatAccount->accountName() << ":stream-notify-room not implemented: "<< object;
     } else if (collection == "stream-notify-logged"_L1) {
@@ -517,7 +570,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
     const QJsonArray contents = fields.value("args"_L1).toArray();
 
     if (collection == "stream-room-messages"_L1) {
-        qDebug() << " RocketChatBackend::slotChanged stream-room-messages " << contents;
+        qCDebug(RUQOLA_LOG) << " RocketChatBackend::slotChanged stream-room-messages " << contents;
         processIncomingMessages(contents, false);
     } else if (collection == "users"_L1) {
         if (mRocketChatAccount->ruqolaLogger()) {
@@ -716,7 +769,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             qDebug() << " DELETE MESSAGE Bulk not IMPLEMENTED yet";
             QString roomId = eventname;
             roomId.remove(QStringLiteral("/deleteMessageBulk"));
-            qDebug() << " deleteMessageBulk " << collection << " object " << object;
+            qDebug() << "UNIMPLEMENT!!!!!! deleteMessageBulk " << collection << " object " << object;
             // QJsonObject({"collection":"stream-notify-room","fields":{"args":[{"excludePinned":false,"ignoreDiscussion":true,"rid":"QgCf8GcnXYW5QXiHN","ts":{"$gt":{"$date":946681200000},"$lt":{"$date":1599602400000}},"users":[]}],"eventName":"QgCf8GcnXYW5QXiHN/deleteMessageBulk"},"id":"id","msg":"changed"})
         } else {
             if (mRocketChatAccount->ruqolaLogger()) {
@@ -777,174 +830,69 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
     }
 }
 
-void RocketChatBackend::clearFilesList()
-{
-    mFiles.clear();
-}
-
-void RocketChatBackend::clearUsersList()
-{
-    mUsers.clear();
-}
-
 void RocketChatBackend::subscribeRegistration()
 {
     qCDebug(RUQOLA_LOG) << "subscribe registration";
     // TODO verify if we don"t send two subscription.
     const QString userId{QString::fromLatin1(mRocketChatAccount->settings()->userId())};
-    {
-        // Subscribe notification.
+    const QStringList listStreamNotifierUser{
+        QStringLiteral("notification"),
+        QStringLiteral("rooms-changed"),
+        QStringLiteral("subscriptions-changed"),
+        QStringLiteral("message"),
+        QStringLiteral("otr"),
+        QStringLiteral("webrtc"),
+        QStringLiteral("video-conference"),
+        QStringLiteral("userData"),
+        QStringLiteral("banners"),
+        QStringLiteral("force_logout"),
+    };
+    for (const QString &str : listStreamNotifierUser) {
         QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("notification"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe room-changed.
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("rooms-changed"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe subscriptions-changed
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("subscriptions-changed"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe message
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("message"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe message
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("otr"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe message
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("webrtc"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe message
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("video-conference"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe avatardata
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("userData"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("banners"))));
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
-    }
-    {
-        // Subscribe force_logout
-        QJsonArray params;
-        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, QStringLiteral("force_logout"))));
+        params.append(QJsonValue(QStringLiteral("%1/%2").arg(userId, str)));
         mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-user"), params);
     }
 
-    //    { // Verify as in RC we don't have it
-    //        const QJsonArray params{QJsonValue(QStringLiteral("video-conference"))};
-    //        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
-    //    }
-    // Sound
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("deleteCustomSound"))};
+    const QStringList listStreamNotifierAll{
+        QStringLiteral("deleteCustomSound"),
+        QStringLiteral("updateCustomSound"),
+        QStringLiteral("deleteEmojiCustom"),
+        QStringLiteral("public-settings-changed"),
+        QStringLiteral("permissions-changed"),
+        QStringLiteral("license"),
+        QStringLiteral("public-info"),
+        QStringLiteral("userData"),
+        QStringLiteral("banners"),
+        QStringLiteral("force_logout"),
+    };
+    for (const QString &str : listStreamNotifierUser) {
+        QJsonArray params;
+        params.append(QJsonValue(str));
         mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
     }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("updateCustomSound"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("deleteEmojiCustom"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("public-settings-changed"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
-    }
-    { // Verify it
-        const QJsonArray params{QJsonValue(QStringLiteral("permissions-changed"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
-    }
-    { // Verify it
-        const QJsonArray params{QJsonValue(QStringLiteral("license"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
-    }
-    { // Verify it
-        const QJsonArray params{QJsonValue(QStringLiteral("public-info"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-all"), params);
-    }
-    // stream-notify-logged
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("updateEmojiCustom"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    // stream-notify-logged
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("deleteEmojiCustom"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    // stream-notify-logged
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("roles-change"))};
+
+    const QStringList listStreamNotifierLogged{
+        QStringLiteral("updateEmojiCustom"),
+        QStringLiteral("deleteEmojiCustom"),
+        QStringLiteral("roles-change"),
+        QStringLiteral("roles-change"),
+        QStringLiteral("updateAvatar"),
+        QStringLiteral("Users:NameChanged"),
+        QStringLiteral("Users:Deleted"),
+        QStringLiteral("banner-changed"),
+        QStringLiteral("deleteCustomUserStatus"),
+        QStringLiteral("updateCustomUserStatus"),
+        QStringLiteral("voip.statuschanged"),
+        QStringLiteral("user-status"),
+        QStringLiteral("permissions-changed"),
+        QStringLiteral("private-settings-changed"),
+    };
+    for (const QString &str : listStreamNotifierLogged) {
+        QJsonArray params;
+        params.append(QJsonValue(str));
         mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
     }
 
-    // stream-notify-logged
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("updateAvatar"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    // stream-notify-logged
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("Users:NameChanged"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    // stream-notify-logged
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("Users:Deleted"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    // stream-notify-logged
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("banner-changed"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("deleteCustomUserStatus"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("updateCustomUserStatus"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("voip.statuschanged"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("user-status"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("permissions-changed"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
-    {
-        const QJsonArray params{QJsonValue(QStringLiteral("private-settings-changed"))};
-        mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-notify-logged"), params);
-    }
     {
         const QJsonArray params{QJsonValue(QStringLiteral("roles"))};
         mRocketChatAccount->ddp()->subscribe(QStringLiteral("stream-roles"), params);
