@@ -8,11 +8,13 @@
 #include "avatarmanager.h"
 #include "connection.h"
 #include "rocketchataccount.h"
+#include "rocketchataccountsettings.h"
 #include "ruqola_debug.h"
 #include <QDateTime>
 #include <QDir>
 #include <QDirIterator>
 #include <QSettings>
+#include <QStandardPaths>
 #include <QTimer>
 #include <QUrlQuery>
 
@@ -30,6 +32,8 @@ RocketChatCache::RocketChatCache(RocketChatAccount *account, QObject *parent)
     auto cleanupTimer = new QTimer(this);
     cleanupTimer->setInterval(1h);
     connect(cleanupTimer, &QTimer::timeout, this, &RocketChatCache::cleanupCache);
+
+    handleMigration();
 }
 
 RocketChatCache::~RocketChatCache()
@@ -126,6 +130,15 @@ void RocketChatCache::cleanupCacheDirectory(const QString &directory)
     }
 }
 
+void RocketChatCache::handleMigration()
+{
+    const int version = mAccount->settings()->cacheVersion();
+    if (version == 0) {
+        removeCache();
+        mAccount->settings()->setCacheVersion(1);
+    }
+}
+
 void RocketChatCache::downloadFile(const QString &url, const QUrl &localFile)
 {
     QFile f(fileCachePath(QUrl(url)));
@@ -183,6 +196,23 @@ QUrl RocketChatCache::soundUrlFromLocalCache(const QString &url)
     return soundUrl;
 }
 
+void RocketChatCache::removeCache()
+{
+    // Don't clear all cache when we create new account
+    if (mAccount->accountName().isEmpty()) {
+        return;
+    }
+    const QString storeCachePath =
+        QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1Char('/') + mAccount->accountName() + QLatin1Char('/');
+    QDir dir(storeCachePath);
+    if (dir.exists()) {
+        qDebug() << "Deleting old cache dir" << storeCachePath;
+        if (!dir.removeRecursively()) {
+            qCWarning(RUQOLA_LOG) << "Impossible to delete cache dir:" << storeCachePath;
+        }
+    }
+}
+
 QUrl RocketChatCache::previewUrlFromLocalCache(const QString &url)
 {
     const QUrl previewUrl = urlFromLocalCache(url, false, ManagerDataPaths::PreviewUrl);
@@ -294,7 +324,7 @@ void RocketChatCache::insertAvatarUrl(const QString &userIdentifier, const QUrl
 {
     mAvatarUrl.insert(userIdentifier, url);
     if (!url.isEmpty() && !fileInCache(url)) {
-        mAccount->restApi()->downloadFile(url, QUrl::fromLocalFile(fileCachePath(url)), {});
+        mAccount->restApi()->downloadFile(url, QUrl::fromLocalFile(fileCachePath(url)), "image/png");
         // this will call slotDataDownloaded
     }
 }
