@@ -42,6 +42,7 @@ public:
     [[nodiscard]] QUrl previewUrlFromLocalCache(const QString &url);
     [[nodiscard]] QUrl avatarUrlFromLocalCache(const QString &url);
     [[nodiscard]] QUrl soundUrlFromLocalCache(const QString &url);
+    void removeCache();
 
 Q_SIGNALS:
     void fileDownloaded(const QString &filePath, const QUrl &cacheImageUrl);
@@ -58,6 +59,7 @@ private:
     LIBRUQOLACORE_NO_EXPORT void loadAvatarCache();
     LIBRUQOLACORE_NO_EXPORT void cleanupCache();
     LIBRUQOLACORE_NO_EXPORT void cleanupCacheDirectory(const QString &directory);
+    LIBRUQOLACORE_NO_EXPORT void handleMigration();
 
     QHash<QString, QUrl> mAvatarUrl;
     QSet<QUrl> mFileInDownload;
