@@ -14,8 +14,8 @@ class LIBRUQOLACORE_EXPORT Role
 public:
     Role();
 
-    [[nodiscard]] QString userId() const;
-    void setUserId(const QString &userId);
+    [[nodiscard]] QByteArray userId() const;
+    void setUserId(const QByteArray &userId);
 
     [[nodiscard]] bool isModerator() const;
     void setIsModerator(bool isModerator);
@@ -38,12 +38,12 @@ public:
     void setUserName(const QString &newUserName);
 
 private:
-    QString mUserId;
+    QByteArray mUserId;
     QString mUserName;
     bool mIsModerator = false;
     bool mIsLeader = false;
     bool mIsOwner = false;
 };
 Q_DECLARE_METATYPE(Role)
-Q_DECLARE_TYPEINFO(Role, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(Role, Q_RELOCATABLE_TYPE);
 LIBRUQOLACORE_EXPORT QDebug operator<<(QDebug d, const Role &t);
