@@ -13,11 +13,12 @@ using namespace Qt::Literals::StringLiterals;
 #include "model/usersforroommodel.h"
 #include "rocketchataccount.h"
 #include "ruqola_debug.h"
+#include "ruqola_memory_management_debug.h"
 #include "textconverter.h"
 
 #include <KLocalizedString>
-
 #include <QCborValue>
+#include <QIcon>
 #include <QJsonArray>
 #include <QJsonDocument>
 
@@ -298,7 +299,6 @@ void Room::parseUpdateRoom(const QJsonObject &json)
         setIgnoredUsers(extractStringList(json, "ignored"_L1));
     }
 
-    // TODO muted ????
     // TODO E2EKey
     setE2eKeyId(json["e2eKeyId"_L1].toString());
 
@@ -339,6 +339,7 @@ void Room::parseUpdateRoom(const QJsonObject &json)
     }
     setUserNames(lstUserNames);
 
+    setMutedUsers(extractStringList(json, "muted"_L1));
     setAvatarETag(json.value("avatarETag"_L1).toString().toLatin1());
     parseDisplaySystemMessage(json);
     parseRetentionInfo(json);
@@ -517,7 +518,7 @@ void Room::setOpen(bool open)
 {
     if (roomStateValue(Room::Open) != open) {
         assignRoomStateValue(Room::Open, open);
-        Q_EMIT openChanged();
+        Q_EMIT openChanged(mRoomId);
     }
 }
 
@@ -702,6 +703,70 @@ void Room::parseInsertRoom(const QJsonObject &json)
     parseTeamInfo(json);
 }
 
+void Room::parseSubscriptionRoom(const QJsonObject &json)
+{
+    QByteArray roomID = json.value("rid"_L1).toString().toLatin1();
+    if (roomID.isEmpty()) {
+        roomID = json.value("_id"_L1).toString().toLatin1();
+    }
+    setRoomId(roomID);
+    setName(json["name"_L1].toString());
+    setFName(json["fname"_L1].toString());
+    setAutoTranslateLanguage(json["autoTranslateLanguage"_L1].toString());
+    setAutoTranslate(json["autoTranslate"_L1].toBool());
+    setJitsiTimeout(Utils::parseDate(QStringLiteral("jitsiTimeout"), json));
+    // topic/announcement/description is not part of update subscription
+    const QString roomType = json.value("t"_L1).toString();
+    setChannelType(Room::roomTypeFromString(roomType));
+    const QJsonValue favoriteValue = json.value("f"_L1);
+    if (!favoriteValue.isUndefined()) {
+        setFavorite(favoriteValue.toBool());
+    }
+    setE2EKey(json["E2EKey"_L1].toString());
+    setReadOnly(json["ro"_L1].toBool());
+
+    setUpdatedAt(Utils::parseDate(QStringLiteral("_updatedAt"), json));
+    setLastSeenAt(Utils::parseDate(QStringLiteral("ls"), json));
+    setUnread(json["unread"_L1].toInt());
+    setUserMentions(json["userMentions"_L1].toInt());
+    setGroupMentions(json["groupMentions"_L1].toInt());
+    setOpen(json["open"_L1].toBool());
+    setAlert(json["alert"_L1].toBool());
+    const QJsonValue blockerValue = json.value("blocker"_L1);
+    if (!blockerValue.isUndefined()) {
+        setBlocker(blockerValue.toBool());
+    } else {
+        setBlocker(false);
+    }
+    // TODO e2ekey
+    // TODO blocked ?
+    const QJsonValue archivedValue = json.value("archived"_L1);
+    if (!archivedValue.isUndefined()) {
+        setArchived(archivedValue.toBool());
+    } else {
+        setArchived(false);
+    }
+
+    parseCommonData(json);
+    parseDisplaySystemMessage(json);
+
+    //    const QJsonValue ownerValue = json.value("u"_L1);
+    //    if (!ownerValue.isUndefined()) {
+    //        const QJsonObject objOwner = ownerValue.toObject();
+    //        setRoomCreatorUserId(objOwner.value("_id"_L1).toString());
+    //        setRoomCreatorUserName(objOwner.value("username"_L1).toString());
+    //    } else {
+    //        //When room is initialized we are the owner. When we update room we have the real
+    //        //owner and if it's empty => we need to clear it.
+    //        setRoomCreatorUserId(QString());
+    //        setRoomCreatorUserName(QString());
+    //    }
+    // qDebug() << " *thus" << *this;
+    mNotificationOptions.parseNotificationOptions(json);
+    parseRetentionInfo(json);
+    // parseTeamInfo(json);
+}
+
 qint64 Room::lastSeenAt() const
 {
     return mLastSeenAt;
@@ -770,71 +835,6 @@ void Room::setIgnoredUsers(const QStringList &users)
     }
 }
 
-void Room::parseSubscriptionRoom(const QJsonObject &json)
-{
-    QByteArray roomID = json.value("rid"_L1).toString().toLatin1();
-    if (roomID.isEmpty()) {
-        roomID = json.value("_id"_L1).toString().toLatin1();
-    }
-    setRoomId(roomID);
-    setName(json["name"_L1].toString());
-    setFName(json["fname"_L1].toString());
-    setAutoTranslateLanguage(json["autoTranslateLanguage"_L1].toString());
-    setAutoTranslate(json["autoTranslate"_L1].toBool());
-    setJitsiTimeout(Utils::parseDate(QStringLiteral("jitsiTimeout"), json));
-    // topic/announcement/description is not part of update subscription
-    const QString roomType = json.value("t"_L1).toString();
-    setChannelType(Room::roomTypeFromString(roomType));
-    const QJsonValue favoriteValue = json.value("f"_L1);
-    if (!favoriteValue.isUndefined()) {
-        setFavorite(favoriteValue.toBool());
-    }
-    setE2EKey(json["E2EKey"_L1].toString());
-    setReadOnly(json["ro"_L1].toBool());
-
-    setUpdatedAt(Utils::parseDate(QStringLiteral("_updatedAt"), json));
-    setLastSeenAt(Utils::parseDate(QStringLiteral("ls"), json));
-    setUnread(json["unread"_L1].toInt());
-    setUserMentions(json["userMentions"_L1].toInt());
-    setGroupMentions(json["groupMentions"_L1].toInt());
-    setOpen(json["open"_L1].toBool());
-    setAlert(json["alert"_L1].toBool());
-    const QJsonValue blockerValue = json.value("blocker"_L1);
-    if (!blockerValue.isUndefined()) {
-        setBlocker(blockerValue.toBool());
-    } else {
-        setBlocker(false);
-    }
-    // TODO e2ekey
-    // TODO blocked ?
-    const QJsonValue archivedValue = json.value("archived"_L1);
-    if (!archivedValue.isUndefined()) {
-        setArchived(archivedValue.toBool());
-    } else {
-        setArchived(false);
-    }
-
-    parseCommonData(json);
-    parseDisplaySystemMessage(json);
-
-    //    const QJsonValue ownerValue = json.value("u"_L1);
-    //    if (!ownerValue.isUndefined()) {
-    //        const QJsonObject objOwner = ownerValue.toObject();
-    //        setRoomCreatorUserId(objOwner.value("_id"_L1).toString());
-    //        setRoomCreatorUserName(objOwner.value("username"_L1).toString());
-    //    } else {
-    //        //When room is initialized we are the owner. When we update room we have the real
-    //        //owner and if it's empty => we need to clear it.
-    //        setRoomCreatorUserId(QString());
-    //        setRoomCreatorUserName(QString());
-    //    }
-    // qDebug() << " *thus" << *this;
-    mNotificationOptions.parseNotificationOptions(json);
-    parseRetentionInfo(json);
-    // parseTeamInfo(json);
-    // TODO add muted
-}
-
 void Room::parseRetentionInfo(const QJsonObject &json)
 {
     const QJsonValue retentionValue = json.value("retention"_L1);
@@ -1144,6 +1144,7 @@ void Room::setRolesForRooms(const Roles &rolesForRooms)
 bool Room::hasPermission(const QString &permission) const
 {
     if (mRocketChatAccount) {
+        // qDebug() << " mRoles " << mRoles << " mRolesForRooms " << mRolesForRooms;
         const QStringList permissionRoles = mRocketChatAccount->permissions(permission);
         for (const QString &role : permissionRoles) {
             if (mRoles.contains(role)) {
@@ -1292,7 +1293,7 @@ void Room::deserialize(Room *r, const QJsonObject &o)
     r->setLastSeenAt(static_cast<qint64>(o["lastSeenAt"_L1].toDouble()));
     r->setNumberMessages(static_cast<qint64>(o["msgs"_L1].toInt()));
 
-    r->setMutedUsers(extractStringList(o, "mutedUsers"_L1));
+    r->setMutedUsers(extractStringList(o, "muted"_L1));
 
     r->setDisplaySystemMessageTypes(extractStringList(o, "systemMessages"_L1));
 
@@ -1407,7 +1408,7 @@ QByteArray Room::serialize(Room *r, bool toBinary)
         o["groupMentions"_L1] = r->groupMentions();
     }
 
-    serializeStringList(o, "mutedUsers"_L1, r->mutedUsers());
+    serializeStringList(o, "muted"_L1, r->mutedUsers());
 
     serializeStringList(o, "ignored"_L1, r->ignoredUsers());
     serializeStringList(o, "tunread"_L1, r->threadUnread());
@@ -1516,6 +1517,15 @@ bool Room::userIsIgnored(const QByteArray &userId)
     return users.contains(QString::fromLatin1(userId));
 }
 
+bool Room::userIsMuted(const QString &username)
+{
+    const QStringList users = mutedUsers();
+    if (users.isEmpty()) {
+        return false;
+    }
+    return users.contains(username);
+}
+
 bool Room::roomIsBlocked() const
 {
     return ((readOnly() && !canChangeRoles()) || archived()) || blocker() || blocked();
@@ -1598,6 +1608,20 @@ RoomExtra *Room::roomExtra()
     return mRoomExtra;
 }
 
+qint64 Room::lastOpenedAt() const
+{
+    if (!mRoomExtra) {
+        return -1;
+    }
+    return mRoomExtra->lastOpenedAt();
+}
+
+void Room::setLastOpenedAt(qint64 newLastOpenedAt)
+{
+    qCDebug(RUQOLA_MEMORY_MANAGEMENT_LOG) << "name " << name() << " newLastOpenedAt " << newLastOpenedAt;
+    roomExtra()->setLastOpenedAt(newLastOpenedAt);
+}
+
 Room::RoomStates Room::roomStates() const
 {
     return mRoomStates;
@@ -1662,4 +1686,12 @@ void Room::clearHistory()
     }
 }
 
+bool Room::canCleanHistory() const
+{
+    if (!mRoomExtra) {
+        return false;
+    }
+    return mRoomExtra->canCleanHistory();
+}
+
 #include "moc_room.cpp"
