@@ -5,12 +5,12 @@
 */
 
 #include "roominfo/roomsinfo.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "ruqola_debug.h"
 #include <QJsonArray>
 #include <QJsonObject>
 
+using namespace Qt::Literals::StringLiterals;
 RoomsInfo::RoomsInfo() = default;
 
 bool RoomsInfo::isEmpty() const
@@ -50,10 +50,10 @@ void RoomsInfo::parseListRooms(const QJsonObject &adminRoomsObj, RoomsInfo::Pars
 {
     QString jsonKeyType;
     switch (type) {
-    case Administrator:
+    case ParseType::Administrator:
         jsonKeyType = QStringLiteral("rooms");
         break;
-    case Directory:
+    case ParseType::Directory:
         jsonKeyType = QStringLiteral("result");
         break;
     }
