@@ -5,7 +5,6 @@
 */
 
 #include "ruqolaserverconfig.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "ruqola_authentication_debug.h"
 #include "ruqola_debug.h"
@@ -14,6 +13,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonObject>
 #include <QRegularExpression>
 #include <QStringList>
+using namespace Qt::Literals::StringLiterals;
 
 RuqolaServerConfig::RuqolaServerConfig() = default;
 
@@ -396,6 +396,7 @@ QDebug operator<<(QDebug d, const RuqolaServerConfig &t)
     d.space() << "embedCacheExpirationDays " << t.embedCacheExpirationDays();
     d.space() << "accountsDefaultUserPreferencesPushNotifications " << t.accountsDefaultUserPreferencesPushNotifications();
     d.space() << "accountsDefaultUserPreferencesDesktopNotifications " << t.accountsDefaultUserPreferencesDesktopNotifications();
+    d.space() << "mPasswordSettings " << t.passwordSettings();
     return d;
 }
 
@@ -416,6 +417,36 @@ RuqolaServerConfig::ConfigWithDefaultValue RuqolaServerConfig::parseConfigWithDe
     return value;
 }
 
+bool RuqolaServerConfig::accountsManuallyApproveNewUsers() const
+{
+    return mAccountsManuallyApproveNewUsers;
+}
+
+void RuqolaServerConfig::setAccountsManuallyApproveNewUsers(bool newAccountsManuallyApproveNewUsers)
+{
+    mAccountsManuallyApproveNewUsers = newAccountsManuallyApproveNewUsers;
+}
+
+RuqolaServerConfig::PasswordSettings RuqolaServerConfig::passwordSettings() const
+{
+    return mPasswordSettings;
+}
+
+void RuqolaServerConfig::setPasswordSettings(const PasswordSettings &newPasswordSettings)
+{
+    mPasswordSettings = newPasswordSettings;
+}
+
+bool RuqolaServerConfig::federationEnabled() const
+{
+    return mFederationEnabled;
+}
+
+void RuqolaServerConfig::setFederationEnabled(bool newFederationEnabled)
+{
+    mFederationEnabled = newFederationEnabled;
+}
+
 bool RuqolaServerConfig::allowEmailNotifications() const
 {
     return mAllowEmailNotifications;
@@ -426,6 +457,16 @@ void RuqolaServerConfig::setAllowEmailNotifications(bool newAllowEmailNotificati
     mAllowEmailNotifications = newAllowEmailNotifications;
 }
 
+bool RuqolaServerConfig::allowEmailVerification() const
+{
+    return mAllowEmailVerification;
+}
+
+void RuqolaServerConfig::setAllowEmailVerification(bool newAllowEmailVerification)
+{
+    mAllowEmailVerification = newAllowEmailVerification;
+}
+
 QString RuqolaServerConfig::accountsDefaultUserPreferencesPushNotifications() const
 {
     return mAccountsDefaultUserPreferencesPushNotifications;
@@ -608,7 +649,13 @@ void RuqolaServerConfig::loadSettings(const QJsonObject &currentConfObject)
         setAccountsDefaultUserPreferencesPushNotifications(value.toString());
     } else if (id == "Accounts_AllowEmailNotifications"_L1) {
         setAllowEmailNotifications(value.toBool());
-    } else {
+    } else if (id == "Accounts_EmailVerification"_L1) {
+        setAllowEmailVerification(value.toBool());
+    } else if (id == "FEDERATION_Enabled"_L1) {
+        setFederationEnabled(value.toBool());
+    } else if (id == "Accounts_ManuallyApproveNewUsers"_L1) {
+        setAccountsManuallyApproveNewUsers(value.toBool());
+    } else if (!mPasswordSettings.loadSettings(id, value)) {
         qCDebug(RUQOLA_LOG) << "Other public settings id " << id << value;
     }
 }
@@ -757,8 +804,25 @@ QByteArray RuqolaServerConfig::serialize(bool toBinary)
         createJsonObject(QStringLiteral("Accounts_Default_User_Preferences_desktopNotifications"), accountsDefaultUserPreferencesDesktopNotifications()));
     array.append(createJsonObject(QStringLiteral("Accounts_Default_User_Preferences_pushNotifications"), accountsDefaultUserPreferencesPushNotifications()));
     array.append(createJsonObject(QStringLiteral("Accounts_AllowEmailNotifications"), allowEmailNotifications()));
+    array.append(createJsonObject(QStringLiteral("Accounts_EmailVerification"), allowEmailVerification()));
+    array.append(createJsonObject(QStringLiteral("FEDERATION_Enabled"), federationEnabled()));
+
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_Enabled"), mPasswordSettings.accountsPasswordPolicyEnabled));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_ForbidRepeatingCharacters"),
+                                  mPasswordSettings.accountsPasswordPolicyForbidRepeatingCharacters));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_AtLeastOneSpecialCharacter"),
+                                  mPasswordSettings.accountsPasswordPolicyAtLeastOneSpecialCharacter));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_AtLeastOneNumber"), mPasswordSettings.accountsPasswordPolicyAtLeastOneNumber));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_AtLeastOneUppercase"), mPasswordSettings.accountsPasswordPolicyAtLeastOneUppercase));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_AtLeastOneLowercase"), mPasswordSettings.accountsPasswordPolicyAtLeastOneLowercase));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_MinLength"), mPasswordSettings.accountsPasswordPolicyMinLength));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_MaxLength"), mPasswordSettings.accountsPasswordPolicyMaxLength));
+    array.append(createJsonObject(QStringLiteral("Accounts_Password_Policy_ForbidRepeatingCharactersCount"),
+                                  mPasswordSettings.accountsPasswordPolicyForbidRepeatingCharactersCount));
+    array.append(createJsonObject(QStringLiteral("Accounts_ManuallyApproveNewUsers"), mAccountsManuallyApproveNewUsers));
 
     o["result"_L1] = array;
+
 #if 0
 } else if (id.contains(regExp)) {
     if (value.toBool()) {
@@ -946,4 +1010,163 @@ void RuqolaServerConfig::loadAccountSettingsFromLocalDataBase(const QByteArray &
     deserialize(newObj);
 }
 
+bool RuqolaServerConfig::PasswordSettings::loadSettings(const QString &id, const QVariant &value)
+{
+    if (id == "Accounts_Password_Policy_Enabled"_L1) {
+        accountsPasswordPolicyEnabled = value.toBool();
+    } else if (id == "Accounts_Password_Policy_ForbidRepeatingCharacters"_L1) {
+        accountsPasswordPolicyForbidRepeatingCharacters = value.toBool();
+    } else if (id == "Accounts_Password_Policy_AtLeastOneSpecialCharacter"_L1) {
+        accountsPasswordPolicyAtLeastOneSpecialCharacter = value.toBool();
+    } else if (id == "Accounts_Password_Policy_AtLeastOneNumber"_L1) {
+        accountsPasswordPolicyAtLeastOneNumber = value.toBool();
+    } else if (id == "Accounts_Password_Policy_AtLeastOneUppercase"_L1) {
+        accountsPasswordPolicyAtLeastOneUppercase = value.toBool();
+    } else if (id == "Accounts_Password_Policy_AtLeastOneLowercase"_L1) {
+        accountsPasswordPolicyAtLeastOneLowercase = value.toBool();
+    } else if (id == "Accounts_Password_Policy_MinLength"_L1) {
+        accountsPasswordPolicyMinLength = value.toInt();
+    } else if (id == "Accounts_Password_Policy_MaxLength"_L1) {
+        accountsPasswordPolicyMaxLength = value.toInt();
+    } else if (id == "Accounts_Password_Policy_ForbidRepeatingCharactersCount"_L1) {
+        accountsPasswordPolicyForbidRepeatingCharactersCount = value.toInt();
+    } else {
+        return false;
+    }
+    return true;
+}
+
+bool RuqolaServerConfig::PasswordSettings::operator==(const PasswordSettings &other) const
+{
+    return accountsPasswordPolicyMinLength == other.accountsPasswordPolicyMinLength && accountsPasswordPolicyMaxLength == other.accountsPasswordPolicyMaxLength
+        && accountsPasswordPolicyForbidRepeatingCharactersCount == other.accountsPasswordPolicyForbidRepeatingCharactersCount
+        && accountsPasswordPolicyEnabled == other.accountsPasswordPolicyEnabled
+        && accountsPasswordPolicyForbidRepeatingCharacters == other.accountsPasswordPolicyForbidRepeatingCharacters
+        && accountsPasswordPolicyAtLeastOneLowercase == other.accountsPasswordPolicyAtLeastOneLowercase
+        && accountsPasswordPolicyAtLeastOneUppercase == other.accountsPasswordPolicyAtLeastOneUppercase
+        && accountsPasswordPolicyAtLeastOneNumber == other.accountsPasswordPolicyAtLeastOneNumber
+        && accountsPasswordPolicyAtLeastOneSpecialCharacter == other.accountsPasswordPolicyAtLeastOneSpecialCharacter;
+}
+
+RuqolaServerConfig::PasswordSettings::PasswordSettingChecks RuqolaServerConfig::PasswordSettings::validatePassword(const QString &str)
+{
+    RuqolaServerConfig::PasswordSettings::PasswordSettingChecks checks = RuqolaServerConfig::PasswordSettings::None;
+    if (!accountsPasswordPolicyEnabled) {
+        return checks;
+    }
+    const int total = str.length();
+    if (total >= accountsPasswordPolicyMinLength) {
+        checks |= RuqolaServerConfig::PasswordSettings::MinLengh;
+    }
+    if (total <= accountsPasswordPolicyMaxLength) {
+        checks |= RuqolaServerConfig::PasswordSettings::MaxLengh;
+    }
+    if (accountsPasswordPolicyForbidRepeatingCharacters) {
+        bool tooManyRepeatingCharatersFound = false;
+        const int maxRepeatingChar = accountsPasswordPolicyForbidRepeatingCharactersCount;
+        int duplicateCharFound = 0;
+        for (int i = 0; i < total; ++i) {
+            const QChar c = str.at(i);
+            for (int j = i; j < total; ++j) {
+                if (str.at(j) == c) {
+                    duplicateCharFound++;
+                } else {
+                    break;
+                }
+            }
+            if (duplicateCharFound > maxRepeatingChar) {
+                tooManyRepeatingCharatersFound = true;
+                break;
+            }
+            duplicateCharFound = 0;
+        }
+        if (!tooManyRepeatingCharatersFound) {
+            checks |= RuqolaServerConfig::PasswordSettings::ForbidRepeatingCharactersCount;
+        }
+    }
+    if (accountsPasswordPolicyAtLeastOneLowercase) {
+        for (const auto &a : str) {
+            if (a.isLower()) {
+                checks |= RuqolaServerConfig::PasswordSettings::AtLeastOneLowercase;
+                break;
+            }
+        }
+    }
+    if (accountsPasswordPolicyAtLeastOneUppercase) {
+        for (const auto &a : str) {
+            if (a.isUpper()) {
+                checks |= RuqolaServerConfig::PasswordSettings::AtLeastOneUppercase;
+                break;
+            }
+        }
+    }
+    if (accountsPasswordPolicyAtLeastOneNumber) {
+        for (const auto &a : str) {
+            if (a.isNumber()) {
+                checks |= RuqolaServerConfig::PasswordSettings::AtLeastOneNumber;
+                break;
+            }
+        }
+    }
+    if (accountsPasswordPolicyAtLeastOneSpecialCharacter) {
+        for (const auto &a : str) {
+            if (a.isSymbol() || a.isPunct()) {
+                checks |= RuqolaServerConfig::PasswordSettings::AtLeastOneSpecialCharacter;
+                break;
+            }
+        }
+    }
+    return checks;
+}
+
+RuqolaServerConfig::PasswordSettings::PasswordSettingChecks RuqolaServerConfig::PasswordSettings::passwordValidChecks() const
+{
+    PasswordSettingChecks currentPolicy = PasswordSettingCheck::None;
+    if (accountsPasswordPolicyEnabled) {
+        if (accountsPasswordPolicyForbidRepeatingCharacters) {
+            currentPolicy |= PasswordSettingCheck::ForbidRepeatingCharactersCount;
+        }
+        if (accountsPasswordPolicyAtLeastOneLowercase) {
+            currentPolicy |= PasswordSettingCheck::AtLeastOneLowercase;
+        }
+        if (accountsPasswordPolicyAtLeastOneUppercase) {
+            currentPolicy |= PasswordSettingCheck::AtLeastOneUppercase;
+        }
+        if (accountsPasswordPolicyAtLeastOneSpecialCharacter) {
+            currentPolicy |= PasswordSettingCheck::AtLeastOneSpecialCharacter;
+        }
+        if (accountsPasswordPolicyAtLeastOneNumber) {
+            currentPolicy |= PasswordSettingCheck::AtLeastOneNumber;
+        }
+        if (accountsPasswordPolicyMinLength > 0) {
+            currentPolicy |= PasswordSettingCheck::MinLengh;
+        }
+        if (accountsPasswordPolicyMaxLength > 0) {
+            currentPolicy |= PasswordSettingCheck::MaxLengh;
+        }
+    }
+    return currentPolicy;
+}
+
+bool RuqolaServerConfig::PasswordSettings::isValidatePassword(PasswordSettingChecks checks) const
+{
+    const auto currentPolicy = passwordValidChecks();
+    // qDebug() << " currentPolicy*************** " << currentPolicy << " checks " << checks;
+    return currentPolicy == checks;
+}
+
+QDebug operator<<(QDebug d, const RuqolaServerConfig::PasswordSettings &t)
+{
+    d.space() << "accountsPasswordPolicyMinLength" << t.accountsPasswordPolicyMinLength;
+    d.space() << "accountsPasswordPolicyMaxLength" << t.accountsPasswordPolicyMaxLength;
+    d.space() << "accountsPasswordPolicyForbidRepeatingCharactersCount" << t.accountsPasswordPolicyForbidRepeatingCharactersCount;
+    d.space() << "accountsPasswordPolicyEnabled" << t.accountsPasswordPolicyEnabled;
+    d.space() << "accountsPasswordPolicyForbidRepeatingCharacters " << t.accountsPasswordPolicyForbidRepeatingCharacters;
+    d.space() << "accountsPasswordPolicyAtLeastOneLowercase" << t.accountsPasswordPolicyAtLeastOneLowercase;
+    d.space() << "accountsPasswordPolicyAtLeastOneUppercase" << t.accountsPasswordPolicyAtLeastOneUppercase;
+    d.space() << "accountsPasswordPolicyAtLeastOneNumber" << t.accountsPasswordPolicyAtLeastOneNumber;
+    d.space() << "accountsPasswordPolicyAtLeastOneSpecialCharacter" << t.accountsPasswordPolicyAtLeastOneSpecialCharacter;
+    return d;
+}
+
 #include "moc_ruqolaserverconfig.cpp"
