@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,14 +15,13 @@ class LIBRUQOLACORE_EXPORT ServerConfigInfo : public QObject
 public:
     explicit ServerConfigInfo(RocketChatAccount *account = nullptr, QObject *parent = nullptr);
     ~ServerConfigInfo() override;
-    Q_REQUIRED_RESULT QString serverVersionStr() const;
-    Q_REQUIRED_RESULT QString accountName() const;
-    Q_REQUIRED_RESULT QString userName() const;
-    Q_REQUIRED_RESULT QString serverUrl() const;
-    Q_REQUIRED_RESULT QString logoUrl() const;
-    Q_REQUIRED_RESULT QString faviconUrl() const;
+    [[nodiscard]] QString serverVersionStr() const;
+    [[nodiscard]] QString accountName() const;
+    [[nodiscard]] QString userName() const;
+    [[nodiscard]] QString serverUrl() const;
+    [[nodiscard]] QString logoUrl() const;
+    [[nodiscard]] QString faviconUrl() const;
 
 private:
-    Q_DISABLE_COPY(ServerConfigInfo)
     RocketChatAccount *const mAccount;
 };
