@@ -34,5 +34,5 @@ private:
 };
 
 Q_DECLARE_METATYPE(ServicePassword)
-Q_DECLARE_TYPEINFO(ServicePassword, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(ServicePassword, Q_RELOCATABLE_TYPE);
 LIBRUQOLACORE_EXPORT QDebug operator<<(QDebug d, const ServicePassword &t);
