@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,8 +20,8 @@ public:
     explicit PurposeMenuWidget(QObject *parent = nullptr);
     ~PurposeMenuWidget() override;
 
-    Q_REQUIRED_RESULT QByteArray text();
-    Q_REQUIRED_RESULT QMenu *menu() const;
+    [[nodiscard]] QByteArray text();
+    [[nodiscard]] QMenu *menu() const;
 
     void setSelectedText(const QString &str);
 
