@@ -38,8 +38,7 @@ Q_SIGNALS:
     void facebookDone(const QString &authToken, const QString &userId);
 
 private:
-    Q_DISABLE_COPY(FacebookAuthJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mAccessToken;
     QString mSecret;
     int mExpireTokenInSeconds = -1;
