@@ -34,8 +34,7 @@ Q_SIGNALS:
     void translateMessageDone();
 
 private:
-    Q_DISABLE_COPY(TranslateMessageJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mMessageId;
     QString mTargetLanguage;
 };
