@@ -31,8 +31,7 @@ Q_SIGNALS:
     void addModeratorDone();
 
 private:
-    Q_DISABLE_COPY(ChannelAddModeratorJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mAddModeratorUserId;
 };
 }
