@@ -14,7 +14,7 @@ class LIBROCKETCHATRESTAPI_QT_EXPORT ChannelCloseJob : public ChannelGroupBaseJo
 {
     Q_OBJECT
 public:
-    enum ChannelType {
+    enum class ChannelType : uint8_t {
         Channel = 0,
         Groups,
         Direct,
@@ -39,8 +39,7 @@ Q_SIGNALS:
     void closeChannelDone();
 
 private:
-    Q_DISABLE_COPY(ChannelCloseJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
-    ChannelType mChannelType = Unknown;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    ChannelType mChannelType = ChannelType::Unknown;
 };
 }
