@@ -15,7 +15,7 @@ class LIBROCKETCHATRESTAPI_QT_EXPORT ChannelMembersJob : public ChannelGroupBase
 {
     Q_OBJECT
 public:
-    enum ChannelType {
+    enum class ChannelType : uint8_t {
         Channel = 0,
         Groups,
         Direct,
@@ -43,8 +43,7 @@ protected:
     [[nodiscard]] QString generateErrorMessage(const QString &errorStr) const override;
 
 private:
-    Q_DISABLE_COPY(ChannelMembersJob)
-    void onGetRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
-    ChannelType mChannelType = Unknown;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onGetRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    ChannelType mChannelType = ChannelType::Unknown;
 };
 }
