@@ -5,7 +5,6 @@
 */
 
 #include "getsnippetedmessagesjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -13,6 +12,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonObject>
 #include <QUrlQuery>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 GetSnippetedMessagesJob::GetSnippetedMessagesJob(QObject *parent)
     : RestApiAbstractJob(parent)
@@ -82,7 +82,7 @@ QNetworkRequest GetSnippetedMessagesJob::request() const
     url.setQuery(queryUrl);
 
     QNetworkRequest request(url);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     addAuthRawHeader(request);
     return request;
