@@ -35,8 +35,7 @@ Q_SIGNALS:
     void getSnippetedMessagesDone(const QJsonObject &obj, const QByteArray &roomId);
 
 private:
-    Q_DISABLE_COPY(GetSnippetedMessagesJob)
-    void onGetRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onGetRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QByteArray mRoomId;
 };
 }
