@@ -82,7 +82,7 @@ QNetworkRequest GetStarredMessagesJob::request() const
     url.setQuery(queryUrl);
 
     QNetworkRequest request(url);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     addAuthRawHeader(request);
     return request;
