@@ -95,7 +95,7 @@ QNetworkRequest SyncThreadMessagesJob::request() const
     url.setQuery(queryUrl);
 
     QNetworkRequest request(url);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     addAuthRawHeader(request);
     return request;
