@@ -70,7 +70,7 @@ QNetworkRequest GetCommandsJob::request() const
 
     QNetworkRequest request(url);
     addAuthRawHeader(request);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     return request;
 }
