@@ -31,8 +31,7 @@ Q_SIGNALS:
     void userStatusDeletedDone();
 
 private:
-    Q_DISABLE_COPY(CustomUserStatusDeleteJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QByteArray mCustomUserStatusId;
 };
 }
