@@ -29,11 +29,10 @@ public:
     void setUserNames(const QStringList &userNames);
 
 Q_SIGNALS:
-    void createDmDone();
+    void createDmDone(const QJsonObject &reply);
 
 private:
-    Q_DISABLE_COPY(CreateDmJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QStringList mUserNames;
 };
 }
