@@ -33,8 +33,7 @@ Q_SIGNALS:
     void archiveGroupsError(const QString &);
 
 private:
-    Q_DISABLE_COPY(ArchiveGroupsJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     bool mArchive = true;
 };
 }
