@@ -32,8 +32,7 @@ Q_SIGNALS:
     void changeDescriptionDone();
 
 private:
-    Q_DISABLE_COPY(ChangeGroupsDescriptionJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mDescription;
 };
 }
