@@ -31,8 +31,7 @@ Q_SIGNALS:
     void changeGroupsnameDone();
 
 private:
-    Q_DISABLE_COPY(ChangeGroupsNameJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mName;
 };
 }
