@@ -31,8 +31,7 @@ Q_SIGNALS:
     void changeTopicDone();
 
 private:
-    Q_DISABLE_COPY(ChangeGroupsTopicJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mTopic;
 };
 }
