@@ -31,8 +31,7 @@ Q_SIGNALS:
     void removeLeaderDone();
 
 private:
-    Q_DISABLE_COPY(GroupRemoveLeaderJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mRemoveUserId;
 };
 }
