@@ -32,8 +32,7 @@ Q_SIGNALS:
     void kickUserDone(const QJsonObject &obj);
 
 private:
-    Q_DISABLE_COPY(GroupsKickJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QByteArray mKickUserId;
 };
 }
