@@ -17,7 +17,7 @@ public:
     explicit SetGroupTypeJob(QObject *parent = nullptr);
     ~SetGroupTypeJob() override;
 
-    enum GroupType {
+    enum GroupType : uint8_t {
         Unknown = 0,
         Private,
         Public,
@@ -38,8 +38,7 @@ Q_SIGNALS:
     void setGroupTypeDone();
 
 private:
-    Q_DISABLE_COPY(SetGroupTypeJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     GroupType mType = Unknown;
 };
 }
