@@ -32,6 +32,8 @@ bool AppsUiInteractionJob::start()
 
 void AppsUiInteractionJob::onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson)
 {
+    Q_UNUSED(replyErrorString)
+    Q_UNUSED(replyJson)
     // qDebug() << " response " << replyErrorString << "replyJson  " << replyJson;
     // It doesn't return success or not!
     Q_EMIT appsUiInteractionDone();
@@ -79,8 +81,8 @@ bool AppsUiInteractionJob::canStart() const
 QNetworkRequest AppsUiInteractionJob::request() const
 {
     const QUrl url = mRestApiMethod->generateUrl(RestApiUtil::RestApiUrlType::AppsUiInteraction,
-                                                 mAppsUiInteractionJobInfo.methodName,
-                                                 RestApiUtil::RestApiUrlExtensionType::Apps);
+                                                 RestApiUtil::RestApiUrlExtensionType::Apps,
+                                                 mAppsUiInteractionJobInfo.methodName);
     QNetworkRequest request(url);
     addAuthRawHeader(request);
     addRequestAttribute(request);
