@@ -97,7 +97,7 @@ QNetworkRequest OauthAppsJob::request() const
 
     QNetworkRequest request(url);
     addAuthRawHeader(request);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     return request;
 }
