@@ -68,7 +68,7 @@ QNetworkRequest PermissionsListAllJob::request() const
     }
     QNetworkRequest request(url);
     addAuthRawHeader(request);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     return request;
 }
