@@ -86,7 +86,7 @@ QNetworkRequest GetDiscussionsJob::request() const
     url.setQuery(queryUrl);
 
     QNetworkRequest request(url);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     addAuthRawHeader(request);
     return request;
