@@ -62,8 +62,7 @@ Q_SIGNALS:
     void changeNotificationDone();
 
 private:
-    Q_DISABLE_COPY(SaveNotificationJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
 
     enum SettingChanged {
         Unknown = 0,
