@@ -31,8 +31,7 @@ Q_SIGNALS:
     void markAsReadDone(const QByteArray &roomId);
 
 private:
-    Q_DISABLE_COPY(MarkRoomAsReadJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QByteArray mRoomId;
 };
 }
