@@ -68,7 +68,7 @@ QNetworkRequest TeamInfoJob::request() const
     url.setQuery(queryUrl);
     QNetworkRequest request(url);
     addAuthRawHeader(request);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     return request;
 }
