@@ -31,8 +31,7 @@ Q_SIGNALS:
     void deleteOwnAccountDone();
 
 private:
-    Q_DISABLE_COPY(DeleteOwnAccountJob)
-    void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
+    LIBROCKETCHATRESTAPI_QT_NO_EXPORT void onPostRequestResponse(const QString &replyErrorString, const QJsonDocument &replyJson) override;
     QString mPassword;
 };
 }
