@@ -55,7 +55,7 @@ QNetworkRequest UserInfoJob::request() const
 
     QNetworkRequest request(url);
     addAuthRawHeader(request);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     return request;
 }
