@@ -54,7 +54,7 @@ QNetworkRequest UsersPresenceJob::request() const
 
     QNetworkRequest request(url);
     addAuthRawHeader(request);
-    addRequestAttribute(request, false);
+    addRequestAttribute(request);
 
     return request;
 }
