@@ -18,7 +18,7 @@ AdministratorUsersWidgetTest::AdministratorUsersWidgetTest(QObject *parent)
 
 void AdministratorUsersWidgetTest::shouldHaveDefaultValues()
 {
-    AdministratorUsersWidget w(AdministratorUsersWidget::All, nullptr);
+    AdministratorUsersWidget w(AdministratorUsersWidget::UsersType::All, nullptr);
     auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
     auto mResultTreeView = w.findChild<QTreeView *>(QStringLiteral("mTreeView"));
