@@ -6,7 +6,12 @@
 
 #include "customuserstatustreewidget.h"
 #include "administratorcustomuserstatuscreatedialog.h"
+#include "connection.h"
+#include "custom/customuserstatuscreatejob.h"
+#include "custom/customuserstatusdeletejob.h"
+#include "custom/customuserstatusupdatejob.h"
 #include "rocketchataccount.h"
+#include "ruqolawidgets_debug.h"
 #include "utils.h"
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -70,12 +75,24 @@ void CustomUserStatusTreeWidget::initialize()
 void CustomUserStatusTreeWidget::addClicked()
 {
     QPointer<AdministratorCustomUserStatusCreateDialog> dlg = new AdministratorCustomUserStatusCreateDialog(this);
+    const CustomUserStatuses statuses = mRocketChatAccount->customUserStatuses();
+    const QList<CustomUserStatus> customUserses = statuses.customUserses();
+    QStringList names;
+    for (const CustomUserStatus &status : customUserses) {
+        names << status.name();
+    }
+    dlg->setExistingCustomUserNames(names);
     if (dlg->exec()) {
         const AdministratorCustomUserStatusCreateWidget::UserStatusInfo info = dlg->userStatusInfo();
         RocketChatRestApi::CustomUserStatusCreateJob::StatusCreateInfo statusCreateInfo;
         statusCreateInfo.name = info.name;
         statusCreateInfo.statusType = Utils::presenceStatusToString(info.statusType);
-        mRocketChatAccount->createCustomUserStatus(statusCreateInfo);
+        auto job = new RocketChatRestApi::CustomUserStatusCreateJob(this);
+        job->setStatusCreateInfo(statusCreateInfo);
+        mRocketChatAccount->restApi()->initializeRestApiJob(job);
+        if (!job->start()) {
+            qCDebug(RUQOLAWIDGETS_LOG) << "Impossible to start CustomUserStatusCreateJob";
+        }
     }
     delete dlg;
 }
@@ -92,6 +109,17 @@ void CustomUserStatusTreeWidget::editClicked()
     AdministratorCustomUserStatusCreateWidget::UserStatusInfo userStatusinfo;
     userStatusinfo.name = userStatus.name();
     userStatusinfo.statusType = userStatus.statusType();
+
+    const CustomUserStatuses statuses = mRocketChatAccount->customUserStatuses();
+    const QList<CustomUserStatus> customUserses = statuses.customUserses();
+    QStringList names;
+    for (const CustomUserStatus &status : customUserses) {
+        if (userStatus.name() != status.name()) {
+            names << status.name();
+        }
+    }
+    dlg->setExistingCustomUserNames(names);
+
     dlg->setUserStatusInfo(userStatusinfo);
     if (dlg->exec()) {
         const AdministratorCustomUserStatusCreateWidget::UserStatusInfo info = dlg->userStatusInfo();
@@ -99,7 +127,13 @@ void CustomUserStatusTreeWidget::editClicked()
         statusUpdateInfo.name = info.name;
         statusUpdateInfo.statusType = Utils::presenceStatusToString(info.statusType);
         statusUpdateInfo.identifier = userStatus.identifier();
-        mRocketChatAccount->updateCustomUserStatus(statusUpdateInfo);
+
+        auto job = new RocketChatRestApi::CustomUserStatusUpdateJob(this);
+        job->setStatusUpdateInfo(statusUpdateInfo);
+        mRocketChatAccount->restApi()->initializeRestApiJob(job);
+        if (!job->start()) {
+            qCDebug(RUQOLAWIDGETS_LOG) << "Impossible to start CustomUserStatusUpdateJob";
+        }
     }
     delete dlg;
 }
@@ -117,7 +151,12 @@ void CustomUserStatusTreeWidget::removeClicked()
                                            i18nc("@title", "Remove Custom User Status"),
                                            KStandardGuiItem::remove(),
                                            KStandardGuiItem::cancel())) {
-        mRocketChatAccount->removeCustomUserStatus(userStatus.identifier());
+        auto job = new RocketChatRestApi::CustomUserStatusDeleteJob(this);
+        job->setCustomUserStatusId(userStatus.identifier());
+        mRocketChatAccount->restApi()->initializeRestApiJob(job);
+        if (!job->start()) {
+            qCDebug(RUQOLAWIDGETS_LOG) << "Impossible to start CustomUserStatusDeleteJob";
+        }
     }
 }
 
