@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,5 +14,5 @@ public:
     explicit AdministratorInvitesFilterProxyModel(QAbstractListModel *model = nullptr, QObject *parent = nullptr);
     ~AdministratorInvitesFilterProxyModel() override;
 
-    Q_REQUIRED_RESULT bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+    [[nodiscard]] bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 };
