@@ -169,7 +169,8 @@ void ModerationReportedMessageConsoleTreeWidget::slotDesactivateUser(const QMode
         job->setActivate(false);
         job->setActivateUserId(userId);
         mRocketChatAccount->restApi()->initializeRestApiJob(job);
-        connect(job, &RocketChatRestApi::SetUserActiveStatusJob::setUserActiveStatusDone, this, [this, index](const QJsonObject &replyObject) {
+        connect(job, &RocketChatRestApi::SetUserActiveStatusJob::setUserActiveStatusDone, this, [this](const QJsonObject &replyObject) {
+            Q_UNUSED(replyObject)
             // TODO delete messages
             slotLoadElements();
         });
