@@ -43,7 +43,7 @@ AdministratorRolesWidget::AdministratorRolesWidget(RocketChatAccount *account, Q
 
     mTreeView->setObjectName(QStringLiteral("mTreeView"));
     mSearchLineWidget->setObjectName(QStringLiteral("mSearchLineWidget"));
-    mSearchLineWidget->setPlaceholderText(i18n("Search roles…"));
+    mSearchLineWidget->setPlaceholderText(i18nc("@info:placeholder", "Search roles…"));
     mSearchLineWidget->setClearButtonEnabled(true);
     KLineEditEventHandler::catchReturnKey(mSearchLineWidget);
 
@@ -98,18 +98,18 @@ void AdministratorRolesWidget::slotCustomContextMenuRequested(const QPoint &pos)
         QMenu menu(this);
         const bool hasEntrepriseSupport = mRocketChatAccount->ruqolaServerConfig()->hasEnterpriseSupport();
         if (mRocketChatAccount->ruqolaServerConfig()->hasEnterpriseSupport()) {
-            menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Add…"), this, &AdministratorRolesWidget::addRole);
+            menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18nc("@action", "Add…"), this, &AdministratorRolesWidget::addRole);
         }
         if (index.isValid()) {
             if (hasEntrepriseSupport) {
-                menu.addAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Modify…"), this, [this, index]() {
+                menu.addAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18nc("@action", "Modify…"), this, [this, index]() {
                     const QModelIndex modelIndex = mTreeView->model()->index(index.row(), AdminRolesModel::Identifier);
                     modifyRole(modelIndex);
                 });
                 menu.addSeparator();
             }
 
-            menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Add Users In Role…"), this, [this, index]() {
+            menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18nc("@action", "Add Users In Role…"), this, [this, index]() {
                 const QModelIndex modelIndex = mTreeView->model()->index(index.row(), AdminRolesModel::Identifier);
                 addUserInRole(modelIndex);
             });
@@ -117,7 +117,7 @@ void AdministratorRolesWidget::slotCustomContextMenuRequested(const QPoint &pos)
             const QModelIndex modelIndex = mTreeView->model()->index(index.row(), AdminRolesModel::Protected);
             if (!modelIndex.data().toBool()) { // Not protected we can delete it.
                 menu.addSeparator();
-                menu.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18n("Remove"), this, [this, index]() {
+                menu.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18nc("@action", "Remove"), this, [this, index]() {
                     const QModelIndex modelIndex = mTreeView->model()->index(index.row(), AdminRolesModel::Identifier);
                     deleteRole(modelIndex);
                 });
