@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ public:
     ~AdministratorRoomsEditWidget() override;
 
     void setRoomEditInfo(const RoomEditInfo &newRoomEditInfo) override;
-    Q_REQUIRED_RESULT RoomEditInfo roomEditInfo() const override;
+    [[nodiscard]] RoomEditInfo roomEditInfo() const override;
 
 private:
     QLineEdit *const mLineEdit;
