@@ -18,11 +18,11 @@ AdministratorInviteUsersWidget::AdministratorInviteUsersWidget(QWidget *parent)
     mainLayout->setContentsMargins({});
     mainLayout->setObjectName(QStringLiteral("formLayout"));
 
-    auto label = new QLabel(i18n("Emails:"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Emails:"), this);
     label->setObjectName(QStringLiteral("label"));
 
     mListEmails->setObjectName(QStringLiteral("mListEmails"));
-    mListEmails->setPlaceholderText(i18n("Use ',' for separate emails"));
+    mListEmails->setPlaceholderText(i18nc("@info:placeholder", "Use ',' for separate emails"));
 
     mainLayout->addWidget(label);
     mainLayout->addWidget(mListEmails);
