@@ -5,17 +5,18 @@
 */
 
 #include "administratoruserswidget.h"
-#include "misc/rolescombobox.h"
-
 #include "administratoradduserdialog.h"
 #include "administratorinviteusersdialog.h"
 #include "administratoruserspendingactiondelegate.h"
 #include "connection.h"
+#include "ddpapi/ddpclient.h"
 #include "dialogs/confirmpassworddialog.h"
 #include "invite/sendinvitationemailjob.h"
+#include "misc/rolescombobox.h"
 #include "misc/searchwithdelaylineedit.h"
 #include "model/adminusersallmodel.h"
 #include "model/adminuserspendingmodel.h"
+#include "model/adminusersstatusmodel.h"
 #include "model/searchtreebasefilterproxymodel.h"
 #include "rocketchataccount.h"
 #include "ruqolawidgets_debug.h"
@@ -44,9 +45,8 @@ AdministratorUsersWidget::AdministratorUsersWidget(AdministratorUsersWidget::Use
     , mUserType(type)
 {
     AdminUsersBaseModel *adminUsersModel = nullptr;
-    if (type == AdministratorUsersWidget::All) {
-        adminUsersModel = new AdminUsersAllModel(this);
-    } else {
+    switch (type) {
+    case AdministratorUsersWidget::UsersType::Pending: {
         adminUsersModel = new AdminUsersPendingModel(this);
         auto delegate = new AdministratorUsersPendingActionDelegate(this);
         connect(delegate, &AdministratorUsersPendingActionDelegate::pendingActionActivated, this, [this](const QModelIndex &index) {
@@ -58,6 +58,15 @@ AdministratorUsersWidget::AdministratorUsersWidget(AdministratorUsersWidget::Use
             }
         });
         mTreeView->setItemDelegateForColumn(AdminUsersPendingModel::PendingActionButton, delegate);
+        break;
+    }
+    case UsersType::All:
+        adminUsersModel = new AdminUsersAllModel(this);
+        break;
+    case UsersType::Desactivated:
+    case UsersType::Activate:
+        adminUsersModel = new AdminUsersStatusModel(this);
+        break;
     }
 
     adminUsersModel->setObjectName("mAdminUsersModel"_L1);
@@ -70,7 +79,7 @@ AdministratorUsersWidget::AdministratorUsersWidget(AdministratorUsersWidget::Use
     mProxyModelModel->setObjectName("mAdminUsersProxyModel"_L1);
     mSearchLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Search users…"));
     mTreeView->setModel(mProxyModelModel);
-    if (type == AdministratorUsersWidget::Pending) {
+    if (type == AdministratorUsersWidget::UsersType::Pending) {
         auto funct = [this](const QModelIndex &left, const QModelIndex &right, bool &useDefaultLessThan) {
             const int leftColumn{left.column()};
             if (leftColumn == AdminUsersPendingModel::PendingActionButton) {
@@ -119,7 +128,7 @@ void AdministratorUsersWidget::slotInviteUsers()
             job->setEmails(emails);
             mRocketChatAccount->restApi()->initializeRestApiJob(job);
             connect(job, &RocketChatRestApi::SendInvitationEmailJob::sendInvitationEmailsDone, this, []() {
-                qDebug() << " Emails send";
+                qCDebug(RUQOLAWIDGETS_LOG) << " Emails send";
             });
             if (!job->start()) {
                 qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start SendInvitationEmailJob job";
@@ -364,9 +373,27 @@ void AdministratorUsersWidget::slotLoadElements(int offset, int count, const QSt
         info.searchName = searchName;
     }
 
-    if (mUserType == Pending) {
+    switch (mUserType) {
+    case UsersType::Pending: {
         info.hasLoggedIn = RocketChatRestApi::UsersListByStatusJob::LoggedStatus::NotLogged;
         info.type = RocketChatRestApi::UsersListByStatusJob::StatusType::User;
+        break;
+    }
+    case UsersType::Desactivated: {
+        info.hasLoggedIn = RocketChatRestApi::UsersListByStatusJob::LoggedStatus::Logged;
+        info.type = RocketChatRestApi::UsersListByStatusJob::StatusType::User;
+        info.status = RocketChatRestApi::UsersListByStatusJob::Status::Deactivated;
+        break;
+    }
+    case UsersType::Activate: {
+        // TODO fix me
+        info.hasLoggedIn = RocketChatRestApi::UsersListByStatusJob::LoggedStatus::Logged;
+        info.type = RocketChatRestApi::UsersListByStatusJob::StatusType::User;
+        info.status = RocketChatRestApi::UsersListByStatusJob::Status::Activated;
+        break;
+    }
+    case UsersType::All:
+        break;
     }
 
     job->setUsersListByStatusJobInfo(info);
