@@ -35,6 +35,7 @@ AccountSettingsWidget::AccountSettingsWidget(RocketChatAccount *account, QWidget
     , mHowManyFailedAttemptsUntilBlockUser(new QSpinBox(this))
     , mTimeUnblockUser(new QSpinBox(this))
     , mHowManyFailedAttemptsUntilBlockByIP(new QSpinBox(this))
+    , mHowManyFailedAttemptsUntilBlockByIPinMinutes(new QSpinBox(this))
     , mSendEmailUserWhenUserActivated(new QCheckBox(i18nc("@option:check", "Send Email to User when User is Activated"), this))
     , mSendEmailUserWhenUserDeactivated(new QCheckBox(i18nc("@option:check", "Send Email to User when User is Deactivated"), this))
     , mRequireNameSignup(new QCheckBox(i18nc("@option:check", "Require Name For Signup"), this))
@@ -52,6 +53,11 @@ AccountSettingsWidget::AccountSettingsWidget(RocketChatAccount *account, QWidget
     , mRegistrationAuthenticationServicesDefaultRoles(new QLineEdit(this))
     , mRegistrationUsersDefaultRoles(new QLineEdit(this))
     , mPasswordReset(new QCheckBox(i18nc("@option:check", "Password Reset"), this))
+    , mLoginLogs(new QCheckBox(i18nc("@option:check", "Log (on console) failed login attempts"), this))
+    , mLoginLogsUsername(new QCheckBox(i18nc("@option:check", "Show Username on failed login attempts logs"), this))
+    , mLoginLogsUseragent(new QCheckBox(i18nc("@option:check", "Show UserAgent on failed login attempts logs"), this))
+    , mLoginLogsClientIp(new QCheckBox(i18nc("@option:check", "Show Client IP on failed login attempts logs"), this))
+    , mLoginLogsForwardedForIp(new QCheckBox(i18nc("@option:check", "Show Forwarded IP on failed login attempts logs"), this))
 {
     mAllowChangeName->setObjectName(QStringLiteral("mAllowChangeName"));
     mMainLayout->addWidget(mAllowChangeName);
@@ -141,6 +147,36 @@ AccountSettingsWidget::AccountSettingsWidget(RocketChatAccount *account, QWidget
                mHowManyFailedAttemptsUntilBlockByIP,
                QStringLiteral("Block_Multiple_Failed_Logins_Attempts_Until_Block_By_Ip"));
 
+    // TODO add missing settings
+    mHowManyFailedAttemptsUntilBlockByIPinMinutes->setObjectName(QStringLiteral("mHowManyFailedAttemptsUntilBlockByIPinMinutes"));
+    addSpinbox(i18n("How many failed attempts until block by IP"),
+               mHowManyFailedAttemptsUntilBlockByIPinMinutes,
+               QStringLiteral("Block_Multiple_Failed_Logins_Time_To_Unblock_By_Ip_In_Minutes"));
+
+    auto loginLogsLabel = createBoldLabel(i18n("Login Logs"));
+    loginLogsLabel->setObjectName(QStringLiteral("loginLogsLabel"));
+    mMainLayout->addWidget(loginLogsLabel);
+
+    mLoginLogs->setObjectName(QStringLiteral("mLoginLogs"));
+    mMainLayout->addWidget(mLoginLogs);
+    connectCheckBox(mLoginLogs, QStringLiteral("Login_Logs_Enabled"));
+
+    mLoginLogsUsername->setObjectName(QStringLiteral("mLoginLogsUsername"));
+    mMainLayout->addWidget(mLoginLogsUsername);
+    connectCheckBox(mLoginLogsUsername, QStringLiteral("Login_Logs_Username"));
+
+    mLoginLogsUseragent->setObjectName(QStringLiteral("mLoginLogsUseragent"));
+    mMainLayout->addWidget(mLoginLogsUseragent);
+    connectCheckBox(mLoginLogsUseragent, QStringLiteral("Login_Logs_UserAgent"));
+
+    mLoginLogsClientIp->setObjectName(QStringLiteral("mLoginLogsClientIp"));
+    mMainLayout->addWidget(mLoginLogsClientIp);
+    connectCheckBox(mLoginLogsClientIp, QStringLiteral("Login_Logs_ClientIp"));
+
+    mLoginLogsForwardedForIp->setObjectName(QStringLiteral("mLoginLogsForwardedForIp"));
+    mMainLayout->addWidget(mLoginLogsForwardedForIp);
+    connectCheckBox(mLoginLogsForwardedForIp, QStringLiteral("mLoginLogsForwardedForIp"));
+
     auto regislationLabel = createBoldLabel(i18n("Registration"));
     regislationLabel->setObjectName(QStringLiteral("regislationLabel"));
     mMainLayout->addWidget(regislationLabel);
@@ -222,6 +258,7 @@ AccountSettingsWidget::~AccountSettingsWidget() = default;
 
 void AccountSettingsWidget::initialize(const QMap<QString, QVariant> &mapSettings)
 {
+    // qDebug() << " mapSettings " << mapSettings;
     initializeWidget(mAllowChangeName, mapSettings, true);
     initializeWidget(mAllowChangeUserProfile, mapSettings, true);
     initializeWidget(mAllowChangeUserAvatar, mapSettings, true);
@@ -242,6 +279,7 @@ void AccountSettingsWidget::initialize(const QMap<QString, QVariant> &mapSetting
     initializeWidget(mHowManyFailedAttemptsUntilBlockUser, mapSettings, 10);
     initializeWidget(mTimeUnblockUser, mapSettings, 5);
     initializeWidget(mHowManyFailedAttemptsUntilBlockByIP, mapSettings, 50);
+    initializeWidget(mHowManyFailedAttemptsUntilBlockByIPinMinutes, mapSettings, 5);
     initializeWidget(mSendEmailUserWhenUserActivated, mapSettings, true);
     initializeWidget(mSendEmailUserWhenUserDeactivated, mapSettings, true);
     initializeWidget(mRequireNameSignup, mapSettings, true);
@@ -260,6 +298,11 @@ void AccountSettingsWidget::initialize(const QMap<QString, QVariant> &mapSetting
     initializeWidget(mRegistrationAuthenticationServicesDefaultRoles, mapSettings, QStringLiteral("user"));
     initializeWidget(mRegistrationUsersDefaultRoles, mapSettings, QStringLiteral("user"));
     initializeWidget(mPasswordReset, mapSettings, true);
+    initializeWidget(mLoginLogs, mapSettings, true);
+    initializeWidget(mLoginLogsUsername, mapSettings, false);
+    initializeWidget(mLoginLogsUseragent, mapSettings, false);
+    initializeWidget(mLoginLogsClientIp, mapSettings, false);
+    initializeWidget(mLoginLogsForwardedForIp, mapSettings, false);
 }
 
 #include "moc_accountsettingswidget.cpp"
