@@ -132,6 +132,9 @@ AdministratorSettingsWidget::AdministratorSettingsWidget(RocketChatAccount *acco
     mTabWidget->addTab(mAnalyticsWidget, i18n("Analytics"));
     if (mRocketChatAccount) {
         connect(mRocketChatAccount, &RocketChatAccount::publicSettingLoaded, this, &AdministratorSettingsWidget::initialize);
+        connect(mRocketChatAccount, &RocketChatAccount::privateSettingLoaded, this, [](const QJsonObject &obj) {
+            qDebug() << " RocketChatAccount::privateSettingLoaded " << obj;
+        });
     }
     updateState(false);
 }
@@ -142,6 +145,7 @@ void AdministratorSettingsWidget::loadSettings()
 {
     // Load from database ?
     mRocketChatAccount->rocketChatBackend()->loadPublicSettingsAdministrator();
+    mRocketChatAccount->rocketChatBackend()->loadPrivateSettingsAdministrator();
 }
 
 void AdministratorSettingsWidget::initialize(const QJsonObject &obj)
