@@ -145,6 +145,11 @@ void AccountSettingsWidgetTest::shouldHaveDefaultValues()
     QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mHowManyFailedAttemptsUntilBlockByIP),
              QStringLiteral("Block_Multiple_Failed_Logins_Attempts_Until_Block_By_Ip"));
 
+    auto mHowManyFailedAttemptsUntilBlockByIPinMinutes = w.findChild<QSpinBox *>(QStringLiteral("mHowManyFailedAttemptsUntilBlockByIPinMinutes"));
+    QVERIFY(mHowManyFailedAttemptsUntilBlockByIPinMinutes);
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mHowManyFailedAttemptsUntilBlockByIPinMinutes),
+             QStringLiteral("Block_Multiple_Failed_Logins_Time_To_Unblock_By_Ip_In_Minutes"));
+
     auto mSendEmailUserWhenUserActivated = w.findChild<QCheckBox *>(QStringLiteral("mSendEmailUserWhenUserActivated"));
     QVERIFY(mSendEmailUserWhenUserActivated);
     QVERIFY(!mSendEmailUserWhenUserActivated->isChecked());
@@ -260,6 +265,40 @@ void AccountSettingsWidgetTest::shouldHaveDefaultValues()
     QVERIFY(!mPasswordReset->isChecked());
     QVERIFY(!mPasswordReset->text().isEmpty());
     QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mPasswordReset), QStringLiteral("Accounts_PasswordReset"));
+
+    auto loginLogsLabel = w.findChild<QLabel *>(QStringLiteral("loginLogsLabel"));
+    QVERIFY(loginLogsLabel);
+    QVERIFY(!loginLogsLabel->text().isEmpty());
+
+    auto mLoginLogs = w.findChild<QCheckBox *>(QStringLiteral("mLoginLogs"));
+    QVERIFY(mLoginLogs);
+    QVERIFY(!mLoginLogs->isChecked());
+    QVERIFY(!mLoginLogs->text().isEmpty());
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mLoginLogs), QStringLiteral("Login_Logs_Enabled"));
+
+    auto mLoginLogsUsername = w.findChild<QCheckBox *>(QStringLiteral("mLoginLogsUsername"));
+    QVERIFY(mLoginLogsUsername);
+    QVERIFY(!mLoginLogsUsername->isChecked());
+    QVERIFY(!mLoginLogsUsername->text().isEmpty());
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mLoginLogsUsername), QStringLiteral("Login_Logs_Username"));
+
+    auto mLoginLogsUseragent = w.findChild<QCheckBox *>(QStringLiteral("mLoginLogsUseragent"));
+    QVERIFY(mLoginLogsUseragent);
+    QVERIFY(!mLoginLogsUseragent->isChecked());
+    QVERIFY(!mLoginLogsUseragent->text().isEmpty());
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mLoginLogsUseragent), QStringLiteral("Login_Logs_UserAgent"));
+
+    auto mLoginLogsClientIp = w.findChild<QCheckBox *>(QStringLiteral("mLoginLogsClientIp"));
+    QVERIFY(mLoginLogsClientIp);
+    QVERIFY(!mLoginLogsClientIp->isChecked());
+    QVERIFY(!mLoginLogsClientIp->text().isEmpty());
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mLoginLogsClientIp), QStringLiteral("Login_Logs_ClientIp"));
+
+    auto mLoginLogsForwardedForIp = w.findChild<QCheckBox *>(QStringLiteral("mLoginLogsForwardedForIp"));
+    QVERIFY(mLoginLogsForwardedForIp);
+    QVERIFY(!mLoginLogsForwardedForIp->isChecked());
+    QVERIFY(!mLoginLogsForwardedForIp->text().isEmpty());
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mLoginLogsForwardedForIp), QStringLiteral("mLoginLogsForwardedForIp"));
 }
 
 #include "moc_accountsettingswidgettest.cpp"
