@@ -34,6 +34,8 @@ GeneralSettingsWidget::GeneralSettingsWidget(RocketChatAccount *account, QWidget
     , mSendStatisticsRocketChat(new QCheckBox(i18nc("@option:check", "Send Statistics to Rocket.Chat"), this))
     , mMaxRoomMembersDisablingMessageNotifications(new QSpinBox(this))
     , mStreamCastAddress(new QLineEdit(this))
+    , mRestApiUpperCountLimit(new QSpinBox(this))
+    , mUseRestForDDPCalls(new QCheckBox(i18nc("@option:check", "Use REST instead of websocket for Meteor calls"), this))
 {
     mEnableFavoriteRooms->setObjectName(QStringLiteral("mEnableFavoriteRooms"));
     mMainLayout->addWidget(mEnableFavoriteRooms);
@@ -144,6 +146,20 @@ GeneralSettingsWidget::GeneralSettingsWidget(RocketChatAccount *account, QWidget
     mStreamCastAddress->setObjectName(QStringLiteral("mStreamCastAddress"));
     addLineEdit(i18n("Stream Cast Address"), mStreamCastAddress, QStringLiteral("Stream_Cast_Address"));
     mStreamCastAddress->setToolTip(i18nc("@info:tooltip", "IP or Host of your Rocket.Chat central Stream Cast. E.g. 192.168.1.1:3000 or localhost:4000"));
+
+    auto restApiLabel = createBoldLabel(i18n("REST API"));
+    restApiLabel->setObjectName(QStringLiteral("restApiLabel"));
+    mMainLayout->addWidget(restApiLabel);
+
+    mRestApiUpperCountLimit->setObjectName(QStringLiteral("mRestApiUpperCountLimit"));
+    mRestApiUpperCountLimit->setMaximum(999);
+    addSpinbox(i18n("What is the maximum number of records the REST API should return (when not unlimited)?"),
+               mRestApiUpperCountLimit,
+               QStringLiteral("API_Upper_Count_Limit"));
+
+    mUseRestForDDPCalls->setObjectName(QStringLiteral("mUseRestForDDPCalls"));
+    mMainLayout->addWidget(mUseRestForDDPCalls);
+    connectCheckBox(mUseRestForDDPCalls, QStringLiteral("API_Use_REST_For_DDP_Calls"));
 }
 
 GeneralSettingsWidget::~GeneralSettingsWidget() = default;
@@ -167,6 +183,8 @@ void GeneralSettingsWidget::initialize(const QMap<QString, QVariant> &mapSetting
     initializeWidget(mMaxRoomMembersDisablingMessageNotifications, mapSettings, 100);
     initializeWidget(mUpdateLatestAvailableVersion, mapSettings, QStringLiteral("0.0.0"));
     initializeWidget(mStreamCastAddress, mapSettings, QString());
+    initializeWidget(mRestApiUpperCountLimit, mapSettings, 100);
+    initializeWidget(mUseRestForDDPCalls, mapSettings, true);
 }
 
 #include "moc_generalsettingswidget.cpp"
