@@ -13,43 +13,43 @@
 
 OauthSettingsWidget::OauthSettingsWidget(RocketChatAccount *account, QWidget *parent)
     : SettingsWidgetBase(account, parent)
-    , mSignWithApple(new QCheckBox(i18n("Sign in with Apple"), this))
+    , mSignWithApple(new QCheckBox(i18nc("@option:check", "Sign in with Apple"), this))
     , mAccountsOAuthAppleId(new QLineEdit(this))
     , mAccountsOAuthAppleIss(new QLineEdit(this))
     , mAccountsOAuthAppleKid(new QLineEdit(this))
-    , mTwitterLogin(new QCheckBox(i18n("Twitter Login"), this))
+    , mTwitterLogin(new QCheckBox(i18nc("@option:check", "Twitter Login"), this))
     , mTwitterId(new QLineEdit(this))
     , mTwitterSecret(new QLineEdit(this))
     , mTwitterCallbackURL(new QLineEdit(this))
-    , mLinkedInLogin(new QCheckBox(i18n("LinkedIn Login"), this))
+    , mLinkedInLogin(new QCheckBox(i18nc("@option:check", "LinkedIn Login"), this))
     , mLinkedInId(new QLineEdit(this))
     , mLinkedInSecret(new QLineEdit(this))
     , mLinkedInCallbackURL(new QLineEdit(this))
     , mProxyHost(new QLineEdit(this))
     , mProxyServices(new QLineEdit(this))
-    , mMeteorLogin(new QCheckBox(i18n("Meteor Login"), this))
+    , mMeteorLogin(new QCheckBox(i18nc("@option:check", "Meteor Login"), this))
     , mMeteorId(new QLineEdit(this))
     , mMeteorSecret(new QLineEdit(this))
     , mMeteorCallbackURL(new QLineEdit(this))
-    , mFacebookLogin(new QCheckBox(i18n("Facebook Login"), this))
+    , mFacebookLogin(new QCheckBox(i18nc("@option:check", "Facebook Login"), this))
     , mFacebookId(new QLineEdit(this))
     , mFacebookSecret(new QLineEdit(this))
     , mFacebookCallbackURL(new QLineEdit(this))
-    , mGithubLogin(new QCheckBox(i18n("Github Login"), this))
+    , mGithubLogin(new QCheckBox(i18nc("@option:check", "Github Login"), this))
     , mGithubId(new QLineEdit(this))
     , mGithubSecret(new QLineEdit(this))
     , mGithubCallbackURL(new QLineEdit(this))
-    , mTokenpassLogin(new QCheckBox(i18n("Tokenpass Login"), this))
+    , mTokenpassLogin(new QCheckBox(i18nc("@option:check", "Tokenpass Login"), this))
     , mTokenpassId(new QLineEdit(this))
     , mTokenpassSecret(new QLineEdit(this))
     , mTokenpassCallbackURL(new QLineEdit(this))
     , mTokenpassServerURL(new QLineEdit(this))
-    , mGoogleLogin(new QCheckBox(i18n("Google Login"), this))
+    , mGoogleLogin(new QCheckBox(i18nc("@option:check", "Google Login"), this))
     , mGoogleId(new QLineEdit(this))
     , mGoogleSecret(new QLineEdit(this))
     , mGoogleCallbackURL(new QLineEdit(this))
     , mDolphinUrl(new QLineEdit(this))
-    , mDolphinEnable(new QCheckBox(i18n("Enable"), this))
+    , mDolphinEnable(new QCheckBox(i18nc("@option:check", "Enable"), this))
     , mDolphinId(new QLineEdit(this))
     , mDolphinSecret(new QLineEdit(this))
 {
