@@ -7,18 +7,23 @@
 #pragma once
 #include "libruqolawidgets_private_export.h"
 #include <QDialog>
-class ApplicationsSettingsDescriptionWidget;
+class RocketChatAccount;
+class ApplicationsSettingsDescriptionTabWidget;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT ApplicationsSettingsDescriptionDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ApplicationsSettingsDescriptionDialog(QWidget *parent = nullptr);
+    explicit ApplicationsSettingsDescriptionDialog(RocketChatAccount *account, QWidget *parent = nullptr);
     ~ApplicationsSettingsDescriptionDialog() override;
 
     void setDescription(const QString &desc);
 
+    void setApplicationId(const QByteArray &appId);
+
+    void setApplicationInstalled(bool state);
+
 private:
     LIBRUQOLAWIDGETS_NO_EXPORT void readConfig();
     LIBRUQOLAWIDGETS_NO_EXPORT void writeConfig();
-    ApplicationsSettingsDescriptionWidget *const mApplicationsSettingsDescriptionWidget;
+    ApplicationsSettingsDescriptionTabWidget *const mApplicationsSettingsDescriptionTabWidget;
 };
