@@ -21,8 +21,8 @@
 
 namespace
 {
-constexpr uint padding = 2;
-constexpr int extraMargins = 2 * padding;
+constexpr ushort padding = 2;
+constexpr ushort extraMargins = 2 * padding;
 }
 
 ChannelListDelegate::ChannelListDelegate(QObject *parent)
@@ -174,12 +174,15 @@ void ChannelListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         }
         QRect mentionRect =
             QRect(layout.unreadRect.x(), layout.unreadRect.y(), qMax(layout.unreadRect.width(), layout.unreadRect.height()), layout.unreadRect.height());
+
+        mentionRect.translate(0, (option.rect.height() - mentionRect.height()) / 2 - 2);
+
         mentionRect.moveRight(layout.unreadRect.right());
         painter->setPen(Qt::NoPen);
         painter->setRenderHint(QPainter::Antialiasing);
         painter->drawEllipse(mentionRect);
         painter->setPen(Qt::white);
-        painter->drawText(layout.unreadRect, Qt::AlignCenter, layout.unreadText);
+        painter->drawText(mentionRect.adjusted(1, -1, 0, 0), Qt::AlignCenter, layout.unreadText);
         painter->restore();
     }
 }
