@@ -7,13 +7,16 @@
 #include "channellistwidget.h"
 using namespace Qt::Literals::StringLiterals;
 
+#include "ddpapi/ddpclient.h"
 #include "model/roomfilterproxymodel.h"
+#include "model/roommodel.h"
 #include "rocketchaturlutils.h"
 #include "ruqola_jitsi_debug.h"
 #include "ruqolawidgets_debug.h"
 
 #include "accountmanager.h"
 #include "rocketchataccount.h"
+#include "rocketchataccountsettings.h"
 #include "ruqola.h"
 #include "ruqolautils.h"
 
@@ -329,9 +332,8 @@ void ChannelListWidget::setLayoutSpacing(int spacing)
 
 void ChannelListWidget::applyChannelSelection()
 {
-    const auto selectedIndex = mChannelView->selectionModel()->currentIndex();
+    const auto selectedIndex = mChannelView->filterModel()->mapToSource(mChannelView->selectionModel()->currentIndex());
     if (selectedIndex.isValid()) {
-        mChannelView->channelSelected(selectedIndex);
         mSearchRoomLineEdit->clear();
     }
 }
