@@ -8,7 +8,6 @@
 
 #include "libruqolawidgets_private_export.h"
 #include <QWidget>
-class RocketChatAccount;
 class QToolButton;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT ConferenceCallWidget : public QWidget
 {
@@ -18,7 +17,7 @@ public:
         bool useCamera = false;
         bool useMic = false;
     };
-    explicit ConferenceCallWidget(RocketChatAccount *account, QWidget *parent = nullptr);
+    explicit ConferenceCallWidget(QWidget *parent = nullptr);
     ~ConferenceCallWidget() override;
 
     [[nodiscard]] ConferenceCallStart conferenceCallInfo() const;
