@@ -41,11 +41,7 @@ ConfigureAccountServerWidget::ConfigureAccountServerWidget(QWidget *parent)
     if (!Ruqola::self()->accountManager()->activitiesManager()->enabled()) {
         ui->configureCurrentActivity->hide();
     } else {
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-        connect(ui->configureCurrentActivity, &QCheckBox::stateChanged, this, &ConfigureAccountServerWidget::slotConfigureAccountFromCurrentActivity);
-#else
         connect(ui->configureCurrentActivity, &QCheckBox::checkStateChanged, this, &ConfigureAccountServerWidget::slotConfigureAccountFromCurrentActivity);
-#endif
     }
 #else
     ui->configureCurrentActivity->hide();
