@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -28,7 +28,7 @@ void ChannelInfoReadOnlyWidgetTest::shouldHaveDefaultValues()
     QCOMPARE(mNameReadOnly->textFormat(), Qt::RichText);
     QCOMPARE(mNameReadOnly->textInteractionFlags(), Qt::TextBrowserInteraction);
     QVERIFY(mNameReadOnly->openExternalLinks());
-
+#if 0 // Now it's loaded on demand
     auto mCommentReadOnly = w.findChild<QLabel *>(QStringLiteral("mCommentReadOnly"));
     QVERIFY(mCommentReadOnly);
     QCOMPARE(mCommentReadOnly->textFormat(), Qt::RichText);
@@ -46,6 +46,7 @@ void ChannelInfoReadOnlyWidgetTest::shouldHaveDefaultValues()
     QCOMPARE(mDescriptionReadOnly->textFormat(), Qt::RichText);
     QCOMPARE(mDescriptionReadOnly->textInteractionFlags(), Qt::TextBrowserInteraction);
     QVERIFY(mDescriptionReadOnly->openExternalLinks());
+#endif
 }
 
 #include "moc_channelinforeadonlywidgettest.cpp"
