@@ -52,6 +52,9 @@ void ConfigureNotificationWidgetTest::shouldHaveDefaultValues()
     auto mDesktopSoundCombobox = topLayout->findChild<QComboBox *>(QStringLiteral("mDesktopSoundCombobox"));
     QVERIFY(mDesktopSoundCombobox);
 
+    auto mPlaySoundToolButton = topLayout->findChild<QToolButton *>(QStringLiteral("mPlaySoundToolButton"));
+    QVERIFY(mPlaySoundToolButton);
+
     auto mobileGroupBox = topLayout->findChild<QGroupBox *>(QStringLiteral("mobileGroupBox"));
     QVERIFY(mobileGroupBox);
     QVERIFY(!mobileGroupBox->title().isEmpty());
