@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,7 +20,7 @@ PlaySoundDialogTest::PlaySoundDialogTest(QObject *parent)
 
 void PlaySoundDialogTest::shouldHaveDefaultValues()
 {
-    PlaySoundDialog w;
+    PlaySoundDialog w(nullptr);
 
     QVERIFY(!w.windowTitle().isEmpty());
 
