@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ public:
     explicit ConfirmPasswordDialog(QWidget *parent = nullptr);
     ~ConfirmPasswordDialog() override;
 
-    Q_REQUIRED_RESULT QString password() const;
+    [[nodiscard]] QString password() const;
 
 private:
     ConfirmPasswordWidget *const mConfirmPasswordWidget;
