@@ -25,7 +25,7 @@ Q_SIGNALS:
     void updateOkButton(bool state);
 
 private:
-    void checkMaximumUsers(bool state);
+    LIBRUQOLAWIDGETS_NO_EXPORT void checkMaximumUsers(bool state);
     AddUsersWidget *const mUsers;
     RocketChatAccount *const mRocketChatAccount;
     QLabel *const mTooManyUsers;
