@@ -10,7 +10,6 @@
 #include "createnewchannelwidget.h"
 #include "libruqolawidgets_private_export.h"
 #include <QDialog>
-class CreateNewChannelWidget;
 class QPushButton;
 class RocketChatAccount;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT CreateNewChannelDialog : public QDialog
@@ -27,5 +26,4 @@ private:
     LIBRUQOLAWIDGETS_NO_EXPORT void writeConfig();
     LIBRUQOLAWIDGETS_NO_EXPORT void readConfig();
     CreateNewChannelWidget *const mCreateNewChannelWidget;
-    QPushButton *mOkButton = nullptr;
 };
