@@ -25,6 +25,7 @@ CreateNewChannelWidget::CreateNewChannelWidget(RocketChatAccount *account, QWidg
     , mBroadcast(new QCheckBox(this))
     , mPrivate(new QCheckBox(this))
     , mEncryptedRoom(new QCheckBox(this))
+    , mFederated(new QCheckBox(this))
     , mMainLayout(new QFormLayout(this))
 {
     mMainLayout->setObjectName(QStringLiteral("mainLayout"));
@@ -43,9 +44,13 @@ CreateNewChannelWidget::CreateNewChannelWidget(RocketChatAccount *account, QWidg
 
     mReadOnly->setObjectName(QStringLiteral("mReadOnly"));
     mReadOnly->setChecked(false);
-    mReadOnly->setToolTip(i18nc("@info:tooltip", "All users in this team can write messages"));
+    mReadOnly->setToolTip(i18nc("@info:tooltip", "Anyone can send new messages"));
     mMainLayout->addRow(i18n("Read-Only:"), mReadOnly);
-    auto label = new QLabel(i18nc("@label:textbox", "Only authorized users can write new messages"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Anyone can send new messages"), this);
+    connect(mReadOnly, &QCheckBox::clicked, this, [this, label](bool checked) {
+        mReadOnly->setToolTip(checked ? i18nc("@info:tooltip", "Only owners can send new messages") : i18nc("@info:tooltip", "Anyone can send new messages"));
+        label->setText(checked ? i18nc("@label:textbox", "Only owners can send new messages") : i18nc("@label:textbox", "Anyone can send new messages"));
+    });
     mMainLayout->addWidget(label);
 
     mBroadcast->setObjectName(QStringLiteral("mBroadcast"));
@@ -65,6 +70,10 @@ CreateNewChannelWidget::CreateNewChannelWidget(RocketChatAccount *account, QWidg
     mEncryptedRoom->setChecked(false);
     mMainLayout->addRow(i18n("Encrypted Room:"), mEncryptedRoom);
 
+    mFederated->setObjectName(QStringLiteral("mFederated"));
+    mFederated->setChecked(false);
+    mMainLayout->addRow(i18n("Federated:"), mFederated);
+
     connect(mChannelName, &ChannelNameValidLineWidget::channelIsValid, this, &CreateNewChannelWidget::slotChangeOkButtonEnabled);
 }
 
@@ -118,6 +127,11 @@ QString CreateNewChannelWidget::topic() const
     return mTopicLineEdit->text();
 }
 
+bool CreateNewChannelWidget::federated() const
+{
+    return mFederated->isChecked();
+}
+
 void CreateNewChannelWidget::setFeatures(CreateNewChannelWidget::Features features)
 {
     bool visible = features & CreateNewChannelWidget::Feature::BroadCast;
@@ -129,6 +143,10 @@ void CreateNewChannelWidget::setFeatures(CreateNewChannelWidget::Features featur
 
     mEncryptedRoom->setVisible(visible);
     mMainLayout->labelForField(mEncryptedRoom)->setVisible(visible);
+
+    visible = features & CreateNewChannelWidget::Feature::Federated;
+    mFederated->setVisible(visible);
+    mMainLayout->labelForField(mFederated)->setVisible(visible);
 }
 
 #include "moc_createnewchannelwidget.cpp"
