@@ -34,13 +34,13 @@ ReportMessageWidget::ReportMessageWidget(QWidget *parent)
 
     mainLayout->addLayout(messageLayout);
 
-    auto lab = new QLabel(i18n("Message:"), this);
+    auto lab = new QLabel(i18nc("@label:textbox", "Message:"), this);
     lab->setObjectName(QStringLiteral("label"));
     messageLayout->addWidget(lab, 0, Qt::AlignTop);
 
     mMessageLineEdit->setObjectName(QStringLiteral("mMessageLineEdit"));
     mMessageLineEdit->setAcceptRichText(false);
-    mMessageLineEdit->setPlaceholderText(i18n("Why you signal this message?"));
+    mMessageLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Why you signal this message?"));
     messageLayout->addWidget(mMessageLineEdit);
     connect(mMessageLineEdit, &KTextEdit::textChanged, this, [this]() {
         Q_EMIT updateOkButton(!mMessageLineEdit->toPlainText().trimmed().isEmpty());
