@@ -7,9 +7,9 @@
 #pragma once
 
 #include "libruqolawidgets_private_export.h"
+#include <QUrl>
 #include <QWidget>
 class QLineEdit;
-class KUrlRequester;
 class QLabel;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT UploadFileWidget : public QWidget
 {
@@ -20,16 +20,15 @@ public:
 
     [[nodiscard]] QString description() const;
     [[nodiscard]] QUrl fileUrl() const;
+    [[nodiscard]] QString fileName() const;
     void setFileUrl(const QUrl &url);
     void setPixmap(const QPixmap &pix);
-    void setAuthorizedMediaTypes(const QStringList &mediaTypes);
-
-Q_SIGNALS:
-    void updateOkButton(bool enabled);
 
 private:
+    QLineEdit *const mFileName;
     QLineEdit *const mDescription;
-    KUrlRequester *const mSelectFile;
     QLabel *const mImagePreview;
-    QLabel *const mFileLabel;
+    QLabel *const mFileNameInfo;
+    QLabel *const mMimeTypeLabel;
+    QUrl mUrl;
 };
