@@ -5,8 +5,8 @@
 */
 
 #include "directorydialogtest.h"
+#include "directory/directorycontainerwidget.h"
 #include "directory/directorydialog.h"
-#include "directory/directorytabwidget.h"
 #include <QDialogButtonBox>
 #include <QStandardPaths>
 #include <QTest>
@@ -20,14 +20,14 @@ DirectoryDialogTest::DirectoryDialogTest(QObject *parent)
 
 void DirectoryDialogTest::shouldHaveDefaultValues()
 {
-    DirectoryDialog d(nullptr);
+    DirectoryDialog d(nullptr, DirectoryWidget::DirectoryType::Room);
     QVERIFY(!d.windowTitle().isEmpty());
 
     auto mainLayout = d.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
 
-    auto mDirectoryTabWidget = d.findChild<DirectoryTabWidget *>(QStringLiteral("mDirectoryTabWidget"));
-    QVERIFY(mDirectoryTabWidget);
+    auto mDirectoryContainerWidget = d.findChild<DirectoryContainerWidget *>(QStringLiteral("mDirectoryContainerWidget"));
+    QVERIFY(mDirectoryContainerWidget);
 
     auto button = d.findChild<QDialogButtonBox *>(QStringLiteral("button"));
     QVERIFY(button);
