@@ -7,20 +7,22 @@
 
 #include <QDialog>
 
+#include "directorywidget.h"
 #include "libruqolawidgets_private_export.h"
-class DirectoryTabWidget;
+class DirectoryContainerWidget;
 class RocketChatAccount;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT DirectoryDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit DirectoryDialog(RocketChatAccount *account, QWidget *parent = nullptr);
+    explicit DirectoryDialog(RocketChatAccount *account, DirectoryWidget::DirectoryType type, QWidget *parent = nullptr);
     ~DirectoryDialog() override;
 
-    void fillTabs();
+Q_SIGNALS:
+    void updateJoinButton(bool status);
 
 private:
     LIBRUQOLAWIDGETS_NO_EXPORT void readConfig();
     LIBRUQOLAWIDGETS_NO_EXPORT void writeConfig();
-    DirectoryTabWidget *const mDirectoryTabWidget;
+    DirectoryContainerWidget *const mDirectoryContainerWidget;
 };
