@@ -21,12 +21,15 @@ public:
     [[nodiscard]] bool isAutorized() const;
     void setIsAutorized(bool newIsAutorized);
 
-    void fillDirectory();
-
     [[nodiscard]] DirectoryWidget *directoryWidget() const;
 
     [[nodiscard]] DirectoryNotAuthorizedWidget *directoryNotAutorizedWidget() const;
 
+    void slotJoin();
+
+Q_SIGNALS:
+    void updateJoinButton(bool status);
+
 private:
     DirectoryWidget *const mDirectoryWidget;
     DirectoryNotAuthorizedWidget *const mDirectoryNotAutorizedWidget;
