@@ -23,5 +23,5 @@ struct AccountImportExportInfo {
 [[nodiscard]] LIBRUQOLAWIDGETS_TESTS_EXPORT QString cachePath();
 };
 LIBRUQOLAWIDGETS_TESTS_EXPORT QDebug operator<<(QDebug d, const ImportExportUtils::AccountImportExportInfo &t);
-Q_DECLARE_TYPEINFO(ImportExportUtils::AccountImportExportInfo, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(ImportExportUtils::AccountImportExportInfo, Q_RELOCATABLE_TYPE);
 Q_DECLARE_METATYPE(ImportExportUtils::AccountImportExportInfo)
