@@ -223,9 +223,4 @@ void RuqolaLoginWidget::showError(const QString &text)
     mFailedError->setText(text);
 }
 
-void RuqolaLoginWidget::slotResetPasswordRequested(const QString &email)
-{
-    mRocketChatAccount->requestNewPassword(email);
-}
-
 #include "moc_ruqolaloginwidget.cpp"
