@@ -7,7 +7,6 @@
 #pragma once
 
 #include "authenticationmanager.h"
-#include "ddpapi/ddpclient.h"
 #include "libruqolawidgets_private_export.h"
 #include <QWidget>
 class QPushButton;
@@ -15,6 +14,7 @@ class QLabel;
 class KBusyIndicatorWidget;
 class TwoAuthenticationPasswordWidget;
 class RuqolaLoginStackWidget;
+class RocketChatAccount;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT RuqolaLoginWidget : public QWidget
 {
     Q_OBJECT
@@ -31,7 +31,6 @@ public:
 private:
     LIBRUQOLAWIDGETS_NO_EXPORT void changeWidgetStatus(bool enabled);
     LIBRUQOLAWIDGETS_NO_EXPORT void slotLogin();
-    LIBRUQOLAWIDGETS_NO_EXPORT void slotResetPasswordRequested(const QString &email);
 
     RuqolaLoginStackWidget *const mRuqolaLoginStackWidget;
     QMetaObject::Connection mUpdatePasswordConnection;
