@@ -5,6 +5,7 @@
 */
 
 #include "myaccountpreferenceconfigurewidgettest.h"
+#include "misc/soundconfigurewidget.h"
 #include "myaccount/myaccountpreferenceconfigurewidget.h"
 #include <QCheckBox>
 #include <QComboBox>
@@ -96,10 +97,10 @@ void MyAccountPreferenceConfigureWidgetTest::shouldHaveDefaultValues()
     QVERIFY(!mReceiveLoginDetectionEmails->text().isEmpty());
     QVERIFY(!mReceiveLoginDetectionEmails->toolTip().isEmpty());
 
-    auto mAutomaticAway = w.findChild<QCheckBox *>(QStringLiteral("mAutomaticAway"));
-    QVERIFY(mAutomaticAway);
-    QVERIFY(!mAutomaticAway->isChecked()); // False by default as we didn't load values yet
-    QVERIFY(!mAutomaticAway->text().isEmpty());
+    auto mAutomaticAways = w.findChild<QCheckBox *>(QStringLiteral("mAutomaticAways"));
+    QVERIFY(mAutomaticAways);
+    QVERIFY(!mAutomaticAways->isChecked()); // False by default as we didn't load values yet
+    QVERIFY(!mAutomaticAways->text().isEmpty());
 
     auto idleTimeLimitLabel = w.findChild<QLabel *>(QStringLiteral("idleTimeLimitLabel"));
     QVERIFY(idleTimeLimitLabel);
@@ -109,6 +110,39 @@ void MyAccountPreferenceConfigureWidgetTest::shouldHaveDefaultValues()
     auto mIdleTimeLimit = w.findChild<QSpinBox *>(QStringLiteral("mIdleTimeLimit"));
     QVERIFY(mIdleTimeLimit);
     QVERIFY(!mIdleTimeLimit->toolTip().isEmpty());
+
+    auto downloadWidget = w.findChild<QWidget *>(QStringLiteral("downloadWidget"));
+    QVERIFY(downloadWidget);
+
+    auto downloadWidgetLayout = downloadWidget->findChild<QVBoxLayout *>(QStringLiteral("downloadWidgetLayout"));
+    QVERIFY(downloadWidgetLayout);
+    QCOMPARE(downloadWidgetLayout->contentsMargins(), QMargins{});
+
+    auto soundWidget = w.findChild<QWidget *>(QStringLiteral("soundWidget"));
+    QVERIFY(soundWidget);
+
+    auto soundWidgetLayout = soundWidget->findChild<QVBoxLayout *>(QStringLiteral("soundWidgetLayout"));
+    QVERIFY(soundWidgetLayout);
+    QCOMPARE(soundWidgetLayout->contentsMargins(), QMargins{});
+
+    auto mSoundNewRoomNotification = soundWidget->findChild<SoundConfigureWidget *>(QStringLiteral("mSoundNewRoomNotification"));
+    QVERIFY(mSoundNewRoomNotification);
+
+    auto mSoundNewMessageNotification = soundWidget->findChild<SoundConfigureWidget *>(QStringLiteral("mSoundNewMessageNotification"));
+    QVERIFY(mSoundNewMessageNotification);
+
+    auto mMuteFocusedConversations = w.findChild<QCheckBox *>(QStringLiteral("mMuteFocusedConversations"));
+    QVERIFY(mMuteFocusedConversations);
+    QVERIFY(!mMuteFocusedConversations->isChecked()); // False by default as we didn't load values yet
+    QVERIFY(!mMuteFocusedConversations->text().isEmpty());
+
+    auto mNotificationsSoundVolume = soundWidget->findChild<QSpinBox *>(QStringLiteral("mNotificationsSoundVolume"));
+    QVERIFY(mNotificationsSoundVolume);
+
+    auto notificationsSoundVolumeLabel = soundWidget->findChild<QLabel *>(QStringLiteral("notificationsSoundVolumeLabel"));
+    QVERIFY(notificationsSoundVolumeLabel);
+    QCOMPARE(notificationsSoundVolumeLabel->textFormat(), Qt::PlainText);
+    QVERIFY(!notificationsSoundVolumeLabel->text().isEmpty());
 }
 
 #include "moc_myaccountpreferenceconfigurewidgettest.cpp"
