@@ -67,7 +67,7 @@ MyAccount2e2ConfigureWidget::~MyAccount2e2ConfigureWidget() = default;
 
 void MyAccount2e2ConfigureWidget::slotResetE2EKey()
 {
-    // TODO it uses "/api/v1/method.call/e2e.resetOwnE2EKey"
+    // it uses "/api/v1/method.call/e2e.resetOwnE2EKey"
     // => use restapi for calling ddp method
     auto job = new RocketChatRestApi::MethodCallJob(this);
     RocketChatRestApi::MethodCallJob::MethodCallJobInfo info;
@@ -76,7 +76,7 @@ void MyAccount2e2ConfigureWidget::slotResetE2EKey()
     job->setMethodCallJobInfo(std::move(info));
     mRocketChatAccount->restApi()->initializeRestApiJob(job);
     // qDebug()<< " mRestApiConnection " << mRestApiConnection->serverUrl();
-    connect(job, &RocketChatRestApi::MethodCallJob::methodCallDone, this, [this](const QJsonObject &replyObject) {
+    connect(job, &RocketChatRestApi::MethodCallJob::methodCallDone, this, [](const QJsonObject &replyObject) {
         qDebug() << " replyObject " << replyObject;
     });
     if (!job->start()) {
