@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,8 +18,8 @@ public:
     explicit MyAccountPersonalAccessCreateWidget(QWidget *parent = nullptr);
     ~MyAccountPersonalAccessCreateWidget() override;
 
-    Q_REQUIRED_RESULT bool bypassTwoFactor() const;
-    Q_REQUIRED_RESULT QString tokenName() const;
+    [[nodiscard]] bool bypassTwoFactor() const;
+    [[nodiscard]] QString tokenName() const;
 Q_SIGNALS:
     void updateOkButton(bool enabled);
 
