@@ -7,11 +7,14 @@
 #pragma once
 
 #include "libruqolawidgets_private_export.h"
+#include "ruqolaserverconfig.h"
 #include "users/registeruserjob.h"
 #include <QWidget>
 class QLineEdit;
-class KPasswordLineEdit;
+class PasswordConfirmWidget;
 class QPushButton;
+class QPlainTextEdit;
+class QLabel;
 class LIBRUQOLAWIDGETS_TESTS_EXPORT RegisterUserWidget : public QWidget
 {
     Q_OBJECT
@@ -21,6 +24,8 @@ public:
 
     [[nodiscard]] RocketChatRestApi::RegisterUserJob::RegisterUserInfo registerUserInfo() const;
 
+    void setPasswordValidChecks(const RuqolaServerConfig::PasswordSettings &passwordSettings);
+    void setManuallyApproveNewUsersRequired(bool manual);
 Q_SIGNALS:
     void updateOkButton(bool b);
     void registerNewAccount();
@@ -31,6 +36,7 @@ private:
     QPushButton *const mRegisterButton;
     QLineEdit *const mUserName;
     QLineEdit *const mEmail;
-    KPasswordLineEdit *const mPasswordLineEdit;
-    KPasswordLineEdit *const mConfirmPasswordLineEdit;
+    PasswordConfirmWidget *const mPasswordConfirmWidget;
+    QPlainTextEdit *const mReasonTextEdit;
+    QLabel *const mReasonLabel;
 };
