@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,8 +17,8 @@ PluginTextMessageWidgetTest::PluginTextMessageWidgetTest(QObject *parent)
 void PluginTextMessageWidgetTest::shouldHaveDefaultValues()
 {
     PluginTextMessageWidget w;
+    w.show();
     QVERIFY(w.text().isEmpty());
-    QVERIFY(!w.isVisible());
     QVERIFY(w.isCloseButtonVisible());
 }
 
