@@ -174,17 +174,17 @@ MessageBlockDelegateHelperBase *MessageListDelegate::blocksHelper(const Block &b
 MessageAttachmentDelegateHelperBase *MessageListDelegate::attachmentsHelper(const MessageAttachment &msgAttach) const
 {
     switch (msgAttach.attachmentType()) {
-    case MessageAttachment::Image:
+    case MessageAttachment::AttachmentType::Image:
         return mHelperAttachmentImage.data();
-    case MessageAttachment::File:
+    case MessageAttachment::AttachmentType::File:
         return mHelperAttachmentFile.data();
-    case MessageAttachment::Video:
+    case MessageAttachment::AttachmentType::Video:
         return mHelperAttachmentVideo.data();
-    case MessageAttachment::Audio:
+    case MessageAttachment::AttachmentType::Audio:
         return mHelperAttachmentSound.data();
-    case MessageAttachment::NormalText:
+    case MessageAttachment::AttachmentType::NormalText:
         return mHelperAttachmentText.data();
-    case MessageAttachment::Unknown:
+    case MessageAttachment::AttachmentType::Unknown:
         qCWarning(RUQOLAWIDGETS_LOG) << "It's an unknown attachment ! It's a bug for sure";
         break;
     }
@@ -434,7 +434,8 @@ bool MessageListDelegate::contextMenu(const QStyleOptionViewItem &option, const
             if (info.roomType != Room::RoomType::Direct) {
                 if (mRocketChatAccount->hasPermission(QStringLiteral("create-d"))) {
                     menu.addSeparator();
-                    auto startPrivateConversationAction = new QAction(i18nc("@action", "Start a Private Conversation"), &menu);
+                    auto startPrivateConversationAction =
+                        new QAction(QIcon::fromTheme(QStringLiteral("document-send-symbolic")), i18nc("@action", "Start a Private Conversation"), &menu);
                     connect(startPrivateConversationAction, &QAction::triggered, this, [this, message]() {
                         Q_EMIT startPrivateConversation(message->username());
                     });
@@ -808,8 +809,9 @@ bool MessageListDelegate::mouseEvent(QEvent *event, const QStyleOptionViewItem &
         if (!message->discussionRoomId().isEmpty()) {
             const QRect discussionRect(layout.usableRect.x(), layout.repliesY + layout.repliesHeight, layout.usableRect.width(), layout.discussionsHeight);
             if (discussionRect.contains(mev->pos())) {
+                // qDebug() << " message->discussionRoomId()*****************" << message->discussionRoomId();
                 // We need to fix rest api first
-                mRocketChatAccount->joinDiscussion(message->discussionRoomId(), QString());
+                mRocketChatAccount->getRoomByTypeAndName(message->discussionRoomId(), QStringLiteral("c"));
                 return true;
             }
         }
