@@ -86,12 +86,14 @@ void MessageListLayoutBase::generateAttachmentBlockAndUrlPreviewLayout(MessageLi
                                                                        const QStyleOptionViewItem &option,
                                                                        const QModelIndex &index) const
 {
-    if (message->attachments().isEmpty() && message->blocks().isEmpty() && message->urls().isEmpty()) {
+    if ((!message->attachments() || (message->attachments() && message->attachments()->messageAttachments().isEmpty()))
+        && (!message->blocks() || (message->blocks() && message->blocks()->isEmpty()))
+        && (!message->urls() || (message->urls() && message->urls()->isEmpty()))) {
         layout.reactionsY = attachmentsY;
     } else {
         int topAttachment = attachmentsY;
-        if (!message->attachments().isEmpty()) {
-            const auto attachments = message->attachments();
+        if (message->attachments() && !message->attachments()->messageAttachments().isEmpty()) {
+            const auto attachments = message->attachments()->messageAttachments();
             QSize attachmentsSize;
             // TODO add spacing between attachment
             for (const MessageAttachment &msgAttach : attachments) {
@@ -110,8 +112,8 @@ void MessageListLayoutBase::generateAttachmentBlockAndUrlPreviewLayout(MessageLi
             layout.attachmentsRect = QRect(textLeft, attachmentsY, attachmentsSize.width(), attachmentsSize.height());
         }
         int topBlock = topAttachment;
-        if (!message->blocks().isEmpty()) {
-            const auto blocks = message->blocks();
+        if (message->blocks() && !message->blocks()->blocks().isEmpty()) {
+            const auto blocks = message->blocks()->blocks();
             QSize blocksSize;
             for (const Block &block : blocks) {
                 const MessageBlockDelegateHelperBase *helper = delegate->blocksHelper(block);
@@ -130,8 +132,8 @@ void MessageListLayoutBase::generateAttachmentBlockAndUrlPreviewLayout(MessageLi
             layout.blocksRect = QRect(textLeft, topBlock, blocksSize.width(), blocksSize.height());
         }
         if (mRocketChatAccount && mRocketChatAccount->previewEmbed()) {
-            if (!message->urls().isEmpty()) {
-                const auto urls = message->urls();
+            if (message->urls() && !message->urls()->isEmpty()) {
+                const auto urls = message->urls()->messageUrls();
                 QSize urlsPreviewSize;
                 int topUrlPreview = topBlock;
                 for (const MessageUrl &url : urls) {
