@@ -12,9 +12,7 @@
 #include "roomheaderwidget.h"
 #include <QPointer>
 #include <QVBoxLayout>
-#include <QWidget>
 
-class RoomHeaderWidget;
 class RocketChatAccount;
 class UsersInRoomFlowWidget;
 class RoomCounterInfoWidget;
@@ -115,6 +113,7 @@ private:
     LIBRUQOLAWIDGETS_NO_EXPORT void createE2eDecodeEncryptionKeyFailedWidget();
     LIBRUQOLAWIDGETS_NO_EXPORT void slotDecodeEncryptionKey();
     LIBRUQOLAWIDGETS_NO_EXPORT void createE2eDecodeEncryptionKeyWidget();
+    LIBRUQOLAWIDGETS_NO_EXPORT void slotRoomExportDone();
 
     Room::RoomType mRoomType = Room::RoomType::Unknown;
 
