@@ -28,10 +28,11 @@ UploadFileProgressStatusWidget::UploadFileProgressStatusWidget(QWidget *parent)
 
     mProgressBar->setObjectName(QStringLiteral("mProgressBar"));
     mProgressBar->setRange(0, 100);
+    mProgressBar->setFormat(i18nc("Percent value; %p is the value, % is the percent sign", "%p%"));
 
     mCancelToolButton->setObjectName(QStringLiteral("mCancelToolButton"));
     mCancelToolButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
-    mCancelToolButton->setToolTip(i18n("Cancel Upload"));
+    mCancelToolButton->setToolTip(i18nc("@info:tooltip", "Cancel Upload"));
     connect(mCancelToolButton, &QToolButton::clicked, this, [this] {
         Q_EMIT cancelUpload(mIdentifier);
     });
