@@ -10,6 +10,7 @@
 #include "administratorsettingsdialog/administratorsettingsdialog.h"
 #include "applicationssettingsdialog/applicationssettingsdialog.h"
 #include "databasedialog/exploredatabasedialog.h"
+#include "directmessage/createdmjob.h"
 #include "explorepermissionsdialog/explorepermissionsdialog.h"
 #include "kcolorscheme_version.h"
 #include "misc/changefontsizemenu.h"
@@ -56,6 +57,7 @@
 #include "teams/teamscreatejob.h"
 #include "whatsnew/whatsnewdialog.h"
 
+#include "rooms/roomstartdiscussionjob.h"
 #include <KActionCollection>
 #include <KColorSchemeManager>
 #include <KConfigGroup>
@@ -82,7 +84,6 @@
 #include <QStatusBar>
 #include <QTemporaryFile>
 #include <QToolButton>
-#include <QWidgetAction>
 
 #include <KColorSchemeMenu>
 
@@ -155,23 +156,22 @@ RuqolaMainWindow::~RuqolaMainWindow()
 
 void RuqolaMainWindow::parseCommandLine(QCommandLineParser *parser)
 {
-    if (parser->isSet(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::MessageUrl))) {
-        const QString messageUrl = parser->value(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::MessageUrl));
+    if (parser->isSet(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::CommandLineName::MessageUrl))) {
+        const QString messageUrl = parser->value(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::CommandLineName::MessageUrl));
         if (!messageUrl.isEmpty()) {
             if (RocketChatUrlUtils::parseUrl(messageUrl)) {
                 return;
             }
         }
     }
-    if (parser->isSet(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::Account))) {
-        const QString loadAccount = parser->value(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::Account));
+    if (parser->isSet(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::CommandLineName::Account))) {
+        const QString loadAccount = parser->value(RuqolaCommandLineParser::commandLineFromEnum(RuqolaCommandLineParser::CommandLineName::Account));
         if (!loadAccount.isEmpty()) {
             Ruqola::self()->setCurrentAccount(loadAccount);
         }
     }
 }
 
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
 void RuqolaMainWindow::slotActivateRequested(const QStringList &arguments, const QString &workingDirectory)
 {
     Q_UNUSED(workingDirectory)
@@ -181,11 +181,13 @@ void RuqolaMainWindow::slotActivateRequested(const QStringList &arguments, const
         parser.parse(arguments);
         parseCommandLine(&parser);
     }
-
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
     KWindowSystem::updateStartupId(windowHandle());
     KWindowSystem::activateWindow(windowHandle());
-}
+#else
+    activateWindow();
 #endif
+}
 
 void RuqolaMainWindow::slotRoomNeedAttention()
 {
@@ -407,9 +409,9 @@ void RuqolaMainWindow::setupActions()
 
     mShowMenuBarAction = KStandardAction::showMenubar(this, &RuqolaMainWindow::slotToggleMenubar, ac);
 
-    KStandardAction::quit(this, &RuqolaMainWindow::slotClose, ac);
-    KStandardAction::preferences(this, &RuqolaMainWindow::slotConfigure, ac);
-    KStandardAction::configureNotifications(this, &RuqolaMainWindow::slotConfigureNotifications, ac);
+    KStandardActions::quit(this, &RuqolaMainWindow::slotClose, ac);
+    KStandardActions::preferences(this, &RuqolaMainWindow::slotConfigure, ac);
+    KStandardActions::configureNotifications(this, &RuqolaMainWindow::slotConfigureNotifications, ac);
 
     auto act = new QAction(i18nc("@action", "Add Server…"), this);
     connect(act, &QAction::triggered, this, &RuqolaMainWindow::slotAddServer);
@@ -546,6 +548,11 @@ void RuqolaMainWindow::setupActions()
     ac->addAction(QStringLiteral("applications_requested_settings"), mInstalledApplications);
     mAdministrationMenu->addAction(mInstalledApplications);
 
+    mPrivateApplications = new QAction(i18nc("@action", "Private Applications…"), this);
+    connect(mPrivateApplications, &QAction::triggered, this, &RuqolaMainWindow::slotPrivateApplicationsSettings);
+    ac->addAction(QStringLiteral("applications_private_settings"), mPrivateApplications);
+    mAdministrationMenu->addAction(mPrivateApplications);
+
     mJoinRoom = new QAction(i18nc("Action which allows to search room", "Join Room…"), this);
     connect(mJoinRoom, &QAction::triggered, this, &RuqolaMainWindow::slotJoinRoom);
     ac->addAction(QStringLiteral("join_room"), mJoinRoom);
@@ -760,6 +767,9 @@ void RuqolaMainWindow::slotCreateTeam()
     if (mCurrentRocketChatAccount->encryptionEnabled()) {
         flags |= CreateNewChannelWidget::Feature::Encrypted;
     }
+    if (mCurrentRocketChatAccount->federationEnabled()) {
+        flags |= CreateNewChannelWidget::Feature::Federated;
+    }
     dlg->setFeatures(flags);
     if (dlg->exec()) {
         RocketChatRestApi::CreateChannelTeamInfo teamInfo = dlg->channelInfo(true);
@@ -767,9 +777,8 @@ void RuqolaMainWindow::slotCreateTeam()
         auto job = new RocketChatRestApi::TeamsCreateJob(this);
         job->setTeamsCreateJobInfo(teamInfo);
         mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
-        connect(job, &RocketChatRestApi::TeamsCreateJob::teamCreateDone, this, []() {
-            qCDebug(RUQOLAWIDGETS_LOG) << " teamCreateDone";
-            // TODO switch to new team ?
+        connect(job, &RocketChatRestApi::TeamsCreateJob::teamCreateDone, this, [this](const QJsonObject &replyObject) {
+            mCurrentRocketChatAccount->extractIdentifier(replyObject, "team"_L1, "_id"_L1);
         });
         if (!job->start()) {
             qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start TeamsCreateJob";
@@ -780,14 +789,43 @@ void RuqolaMainWindow::slotCreateTeam()
 
 void RuqolaMainWindow::slotCreateDiscussion()
 {
-    CreateNewDiscussionDialog dlg(mCurrentRocketChatAccount, this);
-    dlg.exec();
+    QPointer<CreateNewDiscussionDialog> dlg = new CreateNewDiscussionDialog(mCurrentRocketChatAccount, this);
+    if (dlg->exec()) {
+        const CreateNewDiscussionDialog::NewDiscussionInfo info = dlg->newDiscussionInfo();
+        auto job = new RocketChatRestApi::RoomStartDiscussionJob(this);
+        connect(job, &RocketChatRestApi::RoomStartDiscussionJob::startDiscussionDone, this, [this](const QJsonObject &replyObj) {
+            mCurrentRocketChatAccount->extractIdentifier(replyObj, "discussion"_L1, "_id"_L1);
+        });
+        mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
+        job->setParentRoomId(info.channelId);
+
+        job->setDiscussionName(info.discussionName);
+        job->setParentMessageId(dlg->messageId());
+        job->setReplyMessage(info.message);
+        job->setUsers(info.users);
+        if (!job->start()) {
+            qCDebug(RUQOLAWIDGETS_LOG) << "Impossible to start RoomStartDiscussionJob";
+        }
+    }
+    delete dlg;
 }
 
 void RuqolaMainWindow::slotCreateDirectMessages()
 {
-    CreateDirectMessagesDialog dlg(mCurrentRocketChatAccount, this);
-    dlg.exec();
+    QPointer<CreateDirectMessagesDialog> dlg = new CreateDirectMessagesDialog(mCurrentRocketChatAccount, this);
+    if (dlg->exec()) {
+        const QStringList usernames = dlg->userNames();
+        auto job = new RocketChatRestApi::CreateDmJob(this);
+        mCurrentRocketChatAccount->restApi()->initializeRestApiJob(job);
+        connect(job, &RocketChatRestApi::CreateDmJob::createDmDone, this, [this](const QJsonObject &replyObject) {
+            mCurrentRocketChatAccount->extractIdentifier(replyObject, "room"_L1, "_id"_L1);
+        });
+        job->setUserNames(usernames);
+        if (!job->start()) {
+            qCWarning(RUQOLAWIDGETS_LOG) << "Impossible to start createDirectMessage job";
+        }
+    }
+    delete dlg;
 }
 
 void RuqolaMainWindow::slotCreateNewChannel()
@@ -800,6 +838,9 @@ void RuqolaMainWindow::slotCreateNewChannel()
     if (mCurrentRocketChatAccount->encryptionEnabled()) {
         flags |= CreateNewChannelWidget::Feature::Encrypted;
     }
+    if (mCurrentRocketChatAccount->federationEnabled()) {
+        flags |= CreateNewChannelWidget::Feature::Federated;
+    }
     dlg->setFeatures(flags);
     if (dlg->exec()) {
         RocketChatRestApi::CreateChannelTeamInfo info = dlg->channelInfo(false);
@@ -908,7 +949,7 @@ void RuqolaMainWindow::slotShowLog()
                 job->setDeleteTemporaryFile(true);
                 job->start();
             } else {
-                KMessageBox::information(this, i18n("Impossible to open log."), i18nc("@title:window", "Show Log"));
+                KMessageBox::information(this, i18n("Cannot write to log file %1", tempFile.fileName()), i18nc("@title:window", "Show Channel Log"));
             }
         }
     }
@@ -984,6 +1025,10 @@ void RuqolaMainWindow::slotConfigureNotifications()
 void RuqolaMainWindow::slotRegisterNewUser()
 {
     QPointer<RegisterUserDialog> dlg = new RegisterUserDialog(this);
+    if (mCurrentRocketChatAccount) {
+        dlg->setPasswordValidChecks(mCurrentRocketChatAccount->ruqolaServerConfig()->passwordSettings());
+        dlg->setManuallyApproveNewUsersRequired(mCurrentRocketChatAccount->ruqolaServerConfig()->accountsManuallyApproveNewUsers());
+    }
     connect(dlg, &RegisterUserDialog::registerNewAccount, this, [this, dlg]() {
         mCurrentRocketChatAccount->registerNewUser(dlg->registerUserInfo());
     });
@@ -1069,8 +1114,8 @@ void RuqolaMainWindow::createSystemTray()
 
         mContextStatusMenu = mNotification->contextMenu()->addMenu(i18nc("@item:inmenu Instant message presence status", "Status"));
         mContextStatusMenu->menuAction()->setVisible(false);
-        trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Preferences)));
-        trayMenu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::ConfigureNotifications)));
+        trayMenu->addAction(actionCollection()->action(KStandardActions::name(KStandardActions::Preferences)));
+        trayMenu->addAction(actionCollection()->action(KStandardActions::name(KStandardActions::ConfigureNotifications)));
         // Create systray to show notifications on Desktop
         connect(mNotification, &Notification::alert, this, [this]() {
             QApplication::alert(this, 0);
@@ -1121,8 +1166,7 @@ void RuqolaMainWindow::slotUpdateCustomUserStatus()
 
         for (int i = 0; i < mStatusProxyModel->rowCount(); i++) {
             const QModelIndex index = mStatusProxyModel->index(i, 0);
-            QAction *action = mContextStatusMenu->addAction(index.data(Qt::DisplayRole).toString());
-            action->setIcon(index.data(Qt::DecorationRole).value<QIcon>());
+            QAction *action = mContextStatusMenu->addAction(index.data(Qt::DecorationRole).value<QIcon>(), index.data(Qt::DisplayRole).toString());
 
             connect(action, &QAction::triggered, this, [this, index] {
                 mStatusComboBox->setStatus(index.data(StatusModel::StatusRoles::Status).value<User::PresenceStatus>());
@@ -1180,7 +1224,7 @@ void RuqolaMainWindow::updateHamburgerMenu()
     menu->addSeparator();
     menu->addAction(actionCollection()->action(QStringLiteral("logout")));
     menu->addSeparator();
-    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
+    menu->addAction(actionCollection()->action(KStandardActions::name(KStandardActions::Quit)));
     mHamburgerMenu->setMenu(menu);
 }
 
@@ -1247,25 +1291,27 @@ void RuqolaMainWindow::slotExportAccounts()
     dlg.exec();
 }
 
-void RuqolaMainWindow::slotApplicationsSettings()
+void RuqolaMainWindow::applicationSettings(ApplicationsSettingsSearchWidget::Feature feature)
 {
     ApplicationsSettingsDialog dlg(mCurrentRocketChatAccount, this);
-    dlg.setFeature(ApplicationsSettingsSearchWidget::None);
+    dlg.setFeature(feature);
+    dlg.initialize();
     dlg.exec();
 }
 
+void RuqolaMainWindow::slotApplicationsSettings()
+{
+    applicationSettings(ApplicationsSettingsSearchWidget::Feature::None);
+}
+
 void RuqolaMainWindow::slotApplicationsRequestedSettings()
 {
-    ApplicationsSettingsDialog dlg(mCurrentRocketChatAccount, this);
-    dlg.setFeature(ApplicationsSettingsSearchWidget::Requested);
-    dlg.exec();
+    applicationSettings(ApplicationsSettingsSearchWidget::Feature::Requested);
 }
 
 void RuqolaMainWindow::slotApplicationsInstalledSettings()
 {
-    ApplicationsSettingsDialog dlg(mCurrentRocketChatAccount, this);
-    dlg.setFeature(ApplicationsSettingsSearchWidget::Installed);
-    dlg.exec();
+    applicationSettings(ApplicationsSettingsSearchWidget::Feature::Installed);
 }
 
 void RuqolaMainWindow::slotClearRoomHistory()
@@ -1292,4 +1338,9 @@ void RuqolaMainWindow::slotShowRestApiLogsFile()
     job->start();
 }
 
+void RuqolaMainWindow::slotPrivateApplicationsSettings()
+{
+    applicationSettings(ApplicationsSettingsSearchWidget::Feature::Private);
+}
+
 #include "moc_ruqolamainwindow.cpp"
