@@ -18,7 +18,7 @@ public:
     explicit SearchTeamCompletionLineEdit(RocketChatAccount *account, QWidget *parent = nullptr);
     ~SearchTeamCompletionLineEdit() override;
 
-    [[nodiscard]] const QString &teamId() const;
+    [[nodiscard]] const QByteArray &teamId() const;
 
 Q_SIGNALS:
     void teamIdChanged(bool isEmpty);
@@ -29,7 +29,7 @@ private:
     LIBRUQOLAWIDGETS_NO_EXPORT void slotTextChanged(const QString &text);
     LIBRUQOLAWIDGETS_NO_EXPORT void slotComplete(const QModelIndex &index);
     LIBRUQOLAWIDGETS_NO_EXPORT void slotTeamAutoCompleteDone(const QJsonObject &obj);
-    QString mTeamId;
+    QByteArray mTeamId;
     TeamCompleterModel *const mTeamCompleterModel;
     QTimer *const mSearchTimer;
     RocketChatAccount *const mRocketChatAccount;
