@@ -43,7 +43,7 @@ void TeamSearchRoomForTeamWidget::slotAddNewName(const AddTeamRoomCompletionLine
     connect(clickableWidget, &ClickableWidget::removeClickableWidget, this, &TeamSearchRoomForTeamWidget::slotRemoveRoom);
     mFlowLayout->addWidget(clickableWidget);
     mMap.insert(roomName, clickableWidget);
-    Q_EMIT userListChanged(!mMap.isEmpty());
+    Q_EMIT roomListChanged(!mMap.isEmpty());
 }
 
 void TeamSearchRoomForTeamWidget::slotRemoveRoom(const QString &name)
@@ -57,19 +57,19 @@ void TeamSearchRoomForTeamWidget::slotRemoveRoom(const QString &name)
             userWidget->deleteLater();
         }
     }
-    Q_EMIT userListChanged(!mMap.isEmpty());
+    Q_EMIT roomListChanged(!mMap.isEmpty());
 }
 
 QList<QByteArray> TeamSearchRoomForTeamWidget::roomIds() const
 {
-    QList<QByteArray> addUsers;
+    QList<QByteArray> addRooms;
     QMapIterator<QString, ClickableWidget *> i(mMap);
-    addUsers.reserve(mMap.count());
+    addRooms.reserve(mMap.count());
     while (i.hasNext()) {
         i.next();
-        addUsers << i.value()->identifier();
+        addRooms << i.value()->identifier();
     }
-    return addUsers;
+    return addRooms;
 }
 
 #include "moc_teamsearchroomforteamwidget.cpp"
