@@ -18,7 +18,7 @@ TeamSearchRoomWidget::TeamSearchRoomWidget(RocketChatAccount *account, QWidget *
 
     mTeamSearchRoomForTeamWidget->setObjectName(QStringLiteral("mTeamSearchRoomForTeamWidget"));
     vboxLayout->addWidget(mTeamSearchRoomForTeamWidget);
-    connect(mTeamSearchRoomForTeamWidget, &TeamSearchRoomForTeamWidget::userListChanged, this, &TeamSearchRoomWidget::enableOkButton);
+    connect(mTeamSearchRoomForTeamWidget, &TeamSearchRoomForTeamWidget::roomListChanged, this, &TeamSearchRoomWidget::enableOkButton);
 }
 
 TeamSearchRoomWidget::~TeamSearchRoomWidget() = default;
