@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,6 +10,8 @@
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+    // Use specific ruqola name for database path
+    app.setApplicationName(QStringLiteral("ruqola"));
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
