@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -38,7 +38,7 @@ void ThreadMessageWidgetTest::shouldHaveDefaultValues()
     auto mThreadPreview = w.findChild<QLabel *>(QStringLiteral("mThreadPreview"));
     QVERIFY(mThreadPreview);
     QVERIFY(mThreadPreview->wordWrap());
-    QCOMPARE(mThreadPreview->contextMenuPolicy(), Qt::CustomContextMenu);
+    QCOMPARE(mThreadPreview->contextMenuPolicy(), Qt::NoContextMenu);
     QVERIFY(mThreadPreview->text().isEmpty());
 
     auto mRoomWidgetBase = w.findChild<RoomWidgetBase *>(QStringLiteral("mRoomWidgetBase"));
