@@ -27,7 +27,7 @@ class LIBRUQOLAWIDGETS_TESTS_EXPORT ThreadMessageWidget : public QWidget
 public:
     struct LIBRUQOLAWIDGETS_TESTS_EXPORT ThreadMessageInfo {
         Message messageThread;
-        QString threadMessageId;
+        QByteArray threadMessageId;
         QString threadMessagePreview;
         Room *room = nullptr;
         bool threadIsFollowing = false;
@@ -43,10 +43,10 @@ protected:
 
 private:
     LIBRUQOLAWIDGETS_NO_EXPORT void initialize();
-    LIBRUQOLAWIDGETS_NO_EXPORT void slotCreateNewDiscussion(const QString &messageId, const QString &originalMessage);
+    LIBRUQOLAWIDGETS_NO_EXPORT void slotCreateNewDiscussion(const QByteArray &messageId, const QString &originalMessage);
     LIBRUQOLAWIDGETS_NO_EXPORT void updateFollowThreadIcon(bool followThread);
     LIBRUQOLAWIDGETS_NO_EXPORT void slotFollowThreadChanged(bool clicked);
-    QString mThreadMessageId;
+    QByteArray mThreadMessageId;
     QLabel *const mThreadPreview;
     RoomWidgetBase *const mRoomWidgetBase;
     RocketChatAccount *const mRocketChatAccount;
