@@ -13,27 +13,17 @@ class LIBRUQOLAWIDGETS_TESTS_EXPORT WhatsNewComboBoxWidget : public QWidget
 {
     Q_OBJECT
 public:
-    enum VersionType {
-        AllVersion,
-        Version2_0,
-        Version2_1,
-        Version2_2,
-        LastVersion = Version2_2,
-    };
-    Q_ENUM(VersionType)
-
     explicit WhatsNewComboBoxWidget(QWidget *parent = nullptr);
     ~WhatsNewComboBoxWidget() override;
 
-    void initializeVersion(VersionType type);
+    void addVersion(const QString &name, int identifier);
 
-    [[nodiscard]] static QString convertVersionEnumToString(WhatsNewComboBoxWidget::VersionType type);
+    void initializeVersion(int type);
 
 Q_SIGNALS:
-    void versionChanged(WhatsNewComboBoxWidget::VersionType type);
+    void versionChanged(int type);
 
 private:
-    LIBRUQOLAWIDGETS_NO_EXPORT void fillCombobox();
     LIBRUQOLAWIDGETS_NO_EXPORT void slotCurrentIndexChanged(int index);
     QComboBox *const mVersionComboBox;
 };
