@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,14 +12,14 @@
 
 class MessageListView;
 class QLineEdit;
-class MessageModel;
+class MessagesModel;
 class QSpinBox;
 class LoadDataBaseGui : public QWidget
 {
     Q_OBJECT
 public:
     explicit LoadDataBaseGui(QWidget *parent = nullptr);
-    ~LoadDataBaseGui() override = default;
+    ~LoadDataBaseGui() override;
 
 private:
     void slotLoad();
@@ -28,5 +28,5 @@ private:
     QLineEdit *const mAccountName;
     QLineEdit *const mRoomName;
     QSpinBox *const mNumberElement;
-    MessageModel *const mMessageModel;
+    MessagesModel *const mMessageModel;
 };
